function [] = MGF_SUMMARY(fileName, p, logStruct_temp)

if isempty(logStruct_temp)
    logStruct_temp = struct;
end

logStruct_temp = mgfLogInit( logStruct_temp, mfilename(), p, fileName, '', 'msg' );

[ retVal, tStart, tEnd, dataLevel, logStruct_temp ] = mgfParseFilename( fileName, logStruct_temp );

if retVal
   logStruct_temp = mgfLog(logStruct_temp, sprintf('mgfParseFilename returned %d.', retVal), 'error');
   mgfLogDump(logStruct_temp);
   return;
end

load(fileName,'-mat');
[justFilePath,justFileName,justFileExt] = fileparts(fileName);
str = split(justFileName,'_');
savename = string(str(1))+"_"+"SUMMARY"+"_"+string(str(2))+"_"+string(str(3))+"_"+string(str(4));

logStruct.text = [logStruct.text logStruct_temp.text];
logStruct.fileName = logStruct_temp.fileName;
logStruct.callingFileName = logStruct_temp.callingFileName;
logStruct.level = logStruct_temp.level;


[AttitudeData,LocationData,logStruct,errorCode_Attitude,errorCode_Location] = getAttitude(t_fit,logStruct,p);
if errorCode_Attitude ~= 0 
    logStruct = mgfLog(logStruct,sprintf('getAttitude returned an error %d. TERMINATING \n', errorCode_Attitude ),'error');
    mgfLogDump(logStruct);    
    return
end
if errorCode_Location ~= 0 
    logStruct = mgfLog(logStruct,sprintf('getLocationpar returned an error %d. TERMINATING \n', errorCode_Location),'error');
    mgfLogDump(logStruct);    
    return
end
kext = 5;
options = [0 0 0 0 0];
sysaxes = 0;
matlabd = datenum(t_fit);
maginput = zeros(25,numel(matlabd));
x1 = LocationData.ALL(:,1);
x2 = LocationData.ALL(:,2);
x3 = LocationData.ALL(:,3);

%% Obtain Model Field Data

[Bgeo,B] = onera_desp_lib_get_field(kext,options,sysaxes,matlabd,x1,x2,x3,maginput);
Bgei = onera_desp_lib_coord_trans(Bgeo,'geo2gei',t_fit);
Bx_model = zeros(numel(t_fit),1);
By_model = zeros(numel(t_fit),1);
Bz_model = zeros(numel(t_fit),1);
% 
for f = 1:numel(AttitudeData.satX(:,1))
Bx_model(f) = Bgei(f,1)*AttitudeData.satX(f,1)+Bgei(f,2)*AttitudeData.satX(f,2)+Bgei(f,3)*AttitudeData.satX(f,3);
By_model(f) = Bgei(f,1)*AttitudeData.satY(f,1)+Bgei(f,2)*AttitudeData.satY(f,2)+Bgei(f,3)*AttitudeData.satY(f,3);
Bz_model(f) = Bgei(f,1)*AttitudeData.satZ(f,1)+Bgei(f,2)*AttitudeData.satZ(f,2)+Bgei(f,3)*AttitudeData.satZ(f,3);
end
Bmagnitude_In = sqrt(B_Inboard(:,1).^2+ B_Inboard(:,2).^2+B_Inboard(:,3).^2);
Bmagnitude_Out = sqrt(B_Outboard(:,1).^2+B_Outboard(:,2).^2+B_Outboard(:,3).^2);
%% Create Plots

 x = imread('esa_logo.png');
 z = imread('Cassiope_logo.jpg');
figHandle = figure;
figHandle.Units = 'Inch';
figHandle.Position = [0 0 8.5 11];
titleDate = t_fit(1);
titleDate.Format = 'MMMM d, yyyy';
xtime = t_fit;
xtime.Format = 'HH:mm:ss';
xRange = [min(xtime) max(xtime)];
f5 = subplot(6,1,1);
pos = get(gca,'Position');
pos(1) = .1788;
pos(2) = 0.9394;
pos(3) = 0.0796;
pos(4) = 0.0566;
set(gca,'Position',pos);
axis off
imshow(z);
f6 = subplot(6,1,2);
pos = get(gca,'Position');
pos(1) = .7558;
pos(2) = 0.9394;
pos(3) = 0.1096;
pos(4) = 0.0566;
set(gca,'Position',pos);
imshow(x);
axis off

f1 = subplot(6,1,3);
 set(gca,'Position',pos,'OuterPosition',[0,0.739055610961687,1,0.248001213759739])
plot(t_fit,B_Inboard(:,1),'b',t_fit,B_Outboard(:,1),'g',t_fit,Bx_model,'r')
xlim(xRange);
f1.XTick = [xtime(1) xtime(floor(numel(xtime)/4)) xtime(floor(numel(xtime)/2)) xtime(floor(.75*numel(xtime))) xtime(end)];
f1.XTickLabel = [];
f1.YTickLabel = sprintf('%5.0f\n',f1.YTick);
ylabel({'Spacecraft Coordinates','Bx(nT)'},'Interpreter','none','FontName','Calibri','FontSize',10,'FontWeight','bold');
title({'e-POP MGF Summary Plot ';sprintf('%s',titleDate)},'Interpreter','latex','FontName','Calibri','FontSize',16,'FontWeight','bold');
t1=text(.2278,34465,sprintf('Inboard Bx'),'Rotation',90,'FontName','Calibri','FontSize',10,'FontWeight','bold');
     set(t1,'Units','normalized');    
     post1x = get(gca, 'OuterPosition');
     post2x = get(t1, 'Position');
     post2x(1) = 1.015*post1x(3);
     post2x(2) = post1x(4)+.6*post1x(4);
     set(t1,'Position',post2x)
t1=text(.227,64346,sprintf('____'),'Rotation',90,'Color','blue','FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');   
     post3x = get(t1, 'Position');
     post3x(1) = 1.007*post1x(3);
     post3x(2) = post2x(2)-.35*post2x(2);
     set(t1,'Position',post3x)
 t1=text(.2278,136480,sprintf('Outboard Bx'),'Rotation',90,'FontName','Calibri','FontSize',10,'FontWeight','bold');
     set(t1,'Units','normalized');    
     post2x = get(t1, 'Position');
     post2x(1) = 1.035*post1x(3);
     post2x(2) = post1x(4)+.6*post1x(4);
     set(t1,'Position',post2x)
 t1=text(.2283,29700,sprintf('____'),'Rotation',90,'Color','green','FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');       
     set(t1,'Units','normalized');  
     post3x = get(t1, 'Position');
     post3x(1) = 1.027*post1x(3);
     post3x(2) = post2x(2)-.35*post2x(2);
     set(t1,'Position',post3x)
 t1=text(.2304,136480,sprintf('IGRF Bx'),'Rotation',90,'FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');   
     post2x = get(t1, 'Position');
     post2x(1) = 1.055*post1x(3);
     post2x(2) = post1x(4)+.6*post1x(4);
     set(t1,'Position',post2x)
 t1=text(.2296,131390,sprintf('____'),'Rotation',90,'Color','red','FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');    
     post3x = get(t1, 'Position');
     post3x(1) = 1.047*post1x(3);
     post3x(2) = post2x(2)-.35*post2x(2);
     set(t1,'Position',post3x)   
f2 = subplot(6,1,4);
pos = get(f2,'Position');
pos(1) = .13;
pos(2) = .538;
pos(3) = .775;
pos(4) = .187;
set(f2,'Position',pos,'OuterPosition',[0,0.533004752540151,1,0.199939636498162])
plot(t_fit,B_Inboard(:,2),'b',t_fit,B_Outboard(:,2),'g',t_fit,By_model,'r')
xlim(xRange);
f2.XTickLabel = [];
f2.XTick = [xtime(1) xtime(floor(numel(xtime)/4)) xtime(floor(numel(xtime)/2)) xtime(floor(.75*numel(xtime))) xtime(end)];
f2.YTickLabel = sprintf('%5.0f\n',f2.YTick);
ylabel({'Spacecraft Coordinates','By(nT)'},'Interpreter','none','FontName','Calibri','FontSize',10,'FontWeight','bold');
t1=text(.2278,34465,sprintf('Inboard By'),'Rotation',90,'FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');    
     pos2x = get(gca, 'OuterPosition');
     post2x = get(t1, 'Position');
     post2x(1) = 1.015*pos2x(3);
     post2x(2) = pos2x(4)+.5*pos2x(4);
     set(t1,'Position',post2x)
t1=text(.227,64346,sprintf('____'),'Rotation',90,'Color','blue','FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');   
     post3x = get(t1, 'Position');
     post3x(1) = 1.007*pos2x(3);
     post3x(2) = post2x(2)-.5*post2x(2);
     set(t1,'Position',post3x)
 t1=text(.2278,136480,sprintf('Outboard By'),'Rotation',90,'FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');    
     post2x = get(t1, 'Position');
     post2x(1) = 1.035*pos2x(3);
     post2x(2) = pos2x(4)+.5*pos2x(4);
     set(t1,'Position',post2x)
 t1=text(.2283,29700,sprintf('____'),'Rotation',90,'Color','green','FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');       
     set(t1,'Units','normalized');  
     post3x = get(t1, 'Position');
     post3x(1) = 1.027*pos2x(3);
     post3x(2) = post2x(2)-.5*post2x(2);
     set(t1,'Position',post3x)
 t1=text(.2304,136480,sprintf('IGRF By'),'Rotation',90,'FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');   
     post2x = get(t1, 'Position');
     post2x(1) = 1.055*pos2x(3);
     post2x(2) = pos2x(4)+.5*pos2x(4);
     set(t1,'Position',post2x)
 t1=text(.2296,131390,sprintf('____'),'Rotation',90,'Color','red','FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');    
     post3x = get(t1, 'Position');
     post3x(1) = 1.047*pos2x(3);
     post3x(2) = post2x(2)-.5*post2x(2);
     set(t1,'Position',post3x)  
f3 = subplot(6,1,5);
 set(f3,'Position',pos,'OuterPosition',[0,0.320951710501427,1,0.203096578997146])
 plot(t_fit,B_Inboard(:,3),'b',t_fit,B_Outboard(:,3),'g',t_fit,Bz_model,'r')
 xlim(xRange);
 f3.XTick = [xtime(1) xtime(floor(numel(xtime)/4)) xtime(floor(numel(xtime)/2)) xtime(floor(.75*numel(xtime))) xtime(end)];
 f3.XTickLabel = [];
 f3.YTickLabel = sprintf('%5.0f\n',f3.YTick);
 ylabel({'Spacecraft Coordinates','Bz(nT)'},'Interpreter','none','FontName','Calibri','FontSize',10,'FontWeight','bold');
 t1=text(.2278,34465,sprintf('Inboard Bz'),'Rotation',90,'FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');    
     pos3x = get(gca, 'OuterPosition');
     post2x = get(t1, 'Position');
     post2x(1) = 1.015*pos3x(3);
     post2x(2) = pos3x(4)+.4*pos3x(4);
     set(t1,'Position',post2x)
 t1=text(.227,64346,sprintf('____'),'Rotation',90,'Color','blue','FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');   
     post3x = get(t1, 'Position');
     post3x(1) = 1.007*pos3x(3);
     post3x(2) = post2x(2)-.5*post2x(2);
     set(t1,'Position',post3x)
 t1=text(.2278,136480,sprintf('Outboard Bz'),'Rotation',90,'FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');    
     post2x = get(t1, 'Position');
     post2x(1) = 1.035*pos3x(3);
     post2x(2) = pos3x(4)+.4*pos3x(4);
     set(t1,'Position',post2x)
 t1=text(.2283,29700,sprintf('____'),'Rotation',90,'Color','green','FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');       
     set(t1,'Units','normalized');  
     post3x = get(t1, 'Position');
     post3x(1) = 1.027*pos3x(3);
     post3x(2) = post2x(2)-.5*post2x(2);
     set(t1,'Position',post3x)
 t1=text(.2304,136480,sprintf('IGRF Bz'),'Rotation',90,'FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');   
     post2x = get(t1, 'Position');
     post2x(1) = 1.055*pos3x(3);
     post2x(2) = pos3x(4)+.4*pos3x(4);
     set(t1,'Position',post2x)
 t1=text(.2296,131390,sprintf('____'),'Rotation',90,'Color','red','FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');    
     post3x = get(t1, 'Position');
     post3x(1) = 1.047*pos3x(3);
     post3x(2) = post2x(2)-.5*post2x(2);
     set(t1,'Position',post3x)  
f4 = subplot(6,1,6);
plot(t_fit, Bmagnitude_In, 'b', t_fit, Bmagnitude_Out, 'g',t_fit,B,'r');
xlim(xRange);
pos = get(gca,'Position');
pos(1) = .13;
pos(2) = .12;
pos(3) = .775;
pos(4) = .187;
 set(gca,'Position',pos)
%  set(f4,'Position',pos,'OuterPosition',[0,0.09651160840836,1,0.218432780629953])
f4.XTick = [xtime(1) xtime(floor(numel(xtime)/4)) xtime(floor(numel(xtime)/2)) xtime(floor(.75*numel(xtime))) xtime(end)];
f4.XTickLabel = [];
groupX = [f4.XTick]; %// central value of each group
groupY = .1; %// vertical position of texts. Adjust as needed
groupNames = {sprintf('%s',xtime(1)), sprintf('%s',xtime(floor(numel(xtime)/4))), sprintf('%s',xtime(floor(numel(xtime)/2))),sprintf('%s',xtime(floor(.75*numel(xtime)))),sprintf('%s',xtime(end))}; %// note different lengths to test centering
posg = get(gca,'Position');
for g = 1:numel(groupX)
    h = text(groupX(g), groupY, groupNames{g}, 'Fontsize', 9, 'Fontweight', 'bold');
        %// create text for group with appropriate font size and weight
    set(h,'Units','normalized');    
    pos = get(h, 'Position');
    ext = get(h, 'Extent');
    if g == 1
     t1=text(.145,16700,sprintf('Time: '), 'Fontsize', 9, 'Fontweight', 'bold');
     set(t1,'Units','normalized');    
     post = get(t1, 'Position');
     post(1) = pos(1) - 1.7*ext(3);
     post(2) = posg(2)-(5/3)*posg(2);
     set(t1, 'Position', post)
    end
    pos(1) = pos(1) - ext(3)/2; %// horizontally correct position to make it centered
    pos(2) = posg(2)-(5/3)*posg(2);
    set(h, 'Position', pos); %// set corrected position for text
end
groupNames2 = {sprintf('%4.0f',LocationData.ALL(1,1)), sprintf('%4.0f',LocationData.ALL(floor(numel(xtime)/4),1)), sprintf('%4.0f',LocationData.ALL(floor(numel(xtime)/2),1)),sprintf('%4.0f',LocationData.ALL(floor(.75*numel(xtime)),1)),sprintf('%4.0f',LocationData.ALL(end,1))}; %// note different lengths to test centering
for g = 1:numel(groupX)
    h = text(groupX(g), groupY, groupNames2{g}, 'Fontsize', 9, 'Fontweight', 'bold');
        %// create text for group with appropriate font size and weight
    set(h,'Units','normalized');   
    pos = get(h, 'Position');
    ext = get(h, 'Extent');
     if g == 1
     t1=text(.145,15000,sprintf('Alt(km):'), 'Fontsize', 9, 'Fontweight', 'bold');
     set(t1,'Units','normalized');    
     post2 = get(t1, 'Position');
     post2(1) = post(1);
     post2(2) = posg(2)-(13/6)*posg(2);
     set(t1, 'Position', post2)
    end
    pos(1) = pos(1) - ext(3)/2; %// horizontally correct position to make it centered
    pos(2) = posg(2)-(13/6)*posg(2);
    set(h, 'Position', pos); %// set corrected position for text
end
groupNames3 = {sprintf('%3.1f',LocationData.ALL(1,2)), sprintf('%3.1f',LocationData.ALL(floor(numel(xtime)/4),2)), sprintf('%3.1f',LocationData.ALL(floor(numel(xtime)/2),2)),sprintf('%3.1f',LocationData.ALL(floor(.75*numel(xtime)),2)),sprintf('%3.1f',LocationData.ALL(end,2))}; %// note different lengths to test centering
for g = 1:numel(groupX)
    h = text(groupX(g), groupY, groupNames3{g}, 'Fontsize', 9, 'Fontweight', 'bold');
        %// create text for group with appropriate font size and weight
    set(h,'Units','normalized');   
    pos = get(h, 'Position');
    ext = get(h, 'Extent');
    if g == 1
     t1=text(.145,13300,sprintf('Lat: '), 'Fontsize', 9, 'Fontweight', 'bold');
     set(t1,'Units','normalized');    
     post2 = get(t1, 'Position');
     post2(1) = post(1);
     post2(2) = posg(2)-(8/3)*posg(2);
     set(t1, 'Position', post2)
    end
    pos(1) = pos(1) - ext(3)/2; %// horizontally correct position to make it centered
    pos(2) = posg(2)-(8/3)*posg(2);
    set(h, 'Position', pos); %// set corrected position for text
end
groupNames4 = {sprintf('%3.1f',LocationData.ALL(1,3)), sprintf('%3.1f',LocationData.ALL(floor(numel(xtime)/4),3)), sprintf('%3.1f',LocationData.ALL(floor(numel(xtime)/2),3)),sprintf('%3.1f',LocationData.ALL(floor(.75*numel(xtime)),3)),sprintf('%3.1f',LocationData.ALL(end,3))}; %// note different lengths to test centering
for g = 1:numel(groupX)
    h = text(groupX(g), groupY, groupNames4{g}, 'Fontsize', 9, 'Fontweight', 'bold');
        %// create text for group with appropriate font size and weight
    set(h,'Units','normalized');   
    pos = get(h, 'Position');
    ext = get(h, 'Extent');
    if g == 1
     t1=text(.145,11600,sprintf('Lon: '), 'Fontsize', 9, 'Fontweight', 'bold');
     set(t1,'Units','normalized');    
     post2 = get(t1, 'Position');
     post2(1) = post(1);
     post2(2) = posg(2)-(19/6)*posg(2);
     set(t1, 'Position', post2)
    end
    pos(1) = pos(1) - ext(3)/2; %// horizontally correct position to make it centered
    pos(2) = posg(2)-(19/6)*posg(2);
    set(h, 'Position', pos); %// set corrected position for text
end
groupNames5 = {sprintf('%3.1f',LocationData.MAG(1,1)), sprintf('%3.1f',LocationData.MAG(floor(numel(xtime)/4),1)), sprintf('%3.1f',LocationData.MAG(floor(numel(xtime)/2),1)),sprintf('%3.1f',LocationData.MAG(floor(.75*numel(xtime)),1)),sprintf('%3.1f',LocationData.MAG(end,1))}; %// note different lengths to test centering
for g = 1:numel(groupX)
    h = text(groupX(g), groupY, groupNames5{g}, 'Fontsize', 9, 'Fontweight', 'bold');
        %// create text for group with appropriate font size and weight
    set(h,'Units','normalized');   
    pos = get(h, 'Position');
    ext = get(h, 'Extent');
    if g == 1
     t1=text(.145,9900,sprintf('Mlat: '), 'Fontsize', 9, 'Fontweight', 'bold');
     set(t1,'Units','normalized');    
     post2 = get(t1, 'Position');
     post2(1) = post(1);
     post2(2) = posg(2)-(11/3)*posg(2);
     set(t1, 'Position', post2)
    end
    pos(1) = pos(1) - ext(3)/2; %// horizontally correct position to make it centered
    pos(2) = posg(2)-(11/3)*posg(2);
    set(h, 'Position', pos); %// set corrected position for text
end
groupNames6 = {sprintf('%3.3f',LocationData.MAG(1,3)), sprintf('%3.3f',LocationData.MAG(floor(numel(xtime)/4),3)), sprintf('%3.3f',LocationData.MAG(floor(numel(xtime)/2),3)),sprintf('%3.3f',LocationData.MAG(floor(.75*numel(xtime)),3)),sprintf('%3.3f',LocationData.MAG(end,3))}; %// note different lengths to test centering
for g = 1:numel(groupX)
    h = text(groupX(g), groupY, groupNames6{g}, 'Fontsize', 9, 'Fontweight', 'bold');
    set(h,'Units','normalized');   
        %// create text for group with appropriate font size and weight
    pos = get(h, 'Position');
    ext = get(h, 'Extent');
    if g == 1
     t1=text(.145,8200,sprintf('Mlt: '), 'Fontsize', 9, 'Fontweight', 'bold');
     set(t1,'Units','normalized');    
     post2 = get(t1, 'Position');
     post2(1) = post(1);
     post2(2) = posg(2)-(25/6)*posg(2);
     set(t1, 'Position', post2)
    end
    if g == 3
       t2 = text(.1874,4400,sprintf('MGF Summary using %s%s on %s',justFileName,justFileExt,datetime('now')),'Interpreter','none','FontName','Calibri','FontSize',10,'FontWeight','bold','HorizontalAlignment','center');
        set(t2,'Units','normalized');
        post3 = get(t2, 'Position');
        post3(1) = pos(1) - ext(3)/2;
        post3(2) = posg(2)-(17/3)*posg(2);
        set(t2, 'Position', post3,'HorizontalAlignment','center') 
    end
    pos(1) = pos(1) - ext(3)/2; %// horizontally correct position to make it centered
    pos(2) = posg(2)-(25/6)*posg(2);
    set(h, 'Position', pos); %// set corrected position for text
end
t1=text(.2278,34465,sprintf('Inboard B'),'Rotation',90,'FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');    
     pos4x = get(gca, 'OuterPosition');
     post2x = get(t1, 'Position');
     post2x(1) = 1.015*pos4x(3);
     post2x(2) = pos4x(4)+.3*pos4x(4);
     set(t1,'Position',post2x)
t1=text(.227,64346,sprintf('____'),'Rotation',90,'Color','blue','FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');   
     post3x = get(t1, 'Position');
     post3x(1) = 1.007*post1x(3);
     post3x(2) = post2x(2)-.5*post2x(2);
     set(t1,'Position',post3x)
 t1=text(.2278,136480,sprintf('Outboard B'),'Rotation',90,'FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');    
     post2x = get(t1, 'Position');
     post2x(1) = 1.035*pos4x(3);
     post2x(2) = pos4x(4)+.3*pos4x(4);
     set(t1,'Position',post2x)
 t1=text(.2283,29700,sprintf('____'),'Rotation',90,'Color','green','FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');       
     set(t1,'Units','normalized');  
     post3x = get(t1, 'Position');
     post3x(1) = 1.027*pos4x(3);
     post3x(2) = post2x(2)-.5*post2x(2);
     set(t1,'Position',post3x)
 t1=text(.2304,136480,sprintf('IGRF B'),'Rotation',90,'FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');   
     post2x = get(t1, 'Position');
     post2x(1) = 1.055*pos4x(3);
     post2x(2) = pos4x(4)+.3*pos4x(4);
     set(t1,'Position',post2x)
 t1=text(.2296,131390,sprintf('____'),'Rotation',90,'Color','red','FontName','Calibri','FontSize',10,'FontWeight','bold','Interpreter','none');
     set(t1,'Units','normalized');    
     post3x = get(t1, 'Position');
     post3x(1) = 1.047*pos4x(3);
     post3x(2) = post2x(2)-.5*post2x(2);
     set(t1,'Position',post3x)  
ylabel({'Total Field','|B| (nT)'},'FontName','Calibri','FontSize',10,'FontWeight','bold');
f4.YTickLabel = sprintf('%5.0f\n',f4.YTick);
outputFileNameFull = strcat(p.Results.outputPath, filesep, savename);
logStruct = mgfLog(logStruct, sprintf('Saving output file: ''%s''\n', outputFileNameFull), 'info');
saveas(figHandle,outputFileNameFull,'png');


%% Close plot unless interactive mode is set
if ~p.Results.interactive
    close(figHandle);
end

end

