function [coeffs, uncertainty, n] = estimateCoeffByTemp(posTicks, negTicks, titleStr, plot, minTemp, maxTemp)
%UNTITLED3 Summary of this function goes here
%   Detailed explanation goes here

posTicksSel = posTicks.ticks(posTicks.Tebox > minTemp & posTicks.Tebox < maxTemp,:);
negTicksSel = negTicks.ticks(negTicks.Tebox > minTemp & negTicks.Tebox < maxTemp,:);

np = length( posTicksSel );
nn = length( negTicksSel );

if (np > 0 && nn > 0)

    allTicks = [posTicksSel; -negTicksSel];
    n = length( allTicks(:,1) );
    
    allTicks_orig = allTicks;
    tickIndex = 1:numel(allTicks(1,:));
    for i = 1:n
        b = robustfit(tickIndex([1:2 end-1:end]), allTicks(i,[1:2 end-1:end]) );
        allTicks(i,:) = allTicks(i,:)-(b(1)+b(2)*tickIndex);
    end
    
    coeffs = median(allTicks);
    uncertainty = std( allTicks ) / sqrt( n );

    index = 1:numel(posTicks.ticks(1,:));

    if (plot)

        figure;

        subplot(1,3,1)
        p11 = plot(index,transpose(posTicks.ticks),'r');
        hold on
        p12 = plot(index,transpose(negTicks.ticks),'b');
        legend([p11(1) p12(1)], 'Positive ticks','Negative Ticks');


        subplot(1,3,2)
        p21 = plot(index,transpose(posTicks.ticks),'r');
        hold on;
        p22 = plot(index,-transpose(negTicks.ticks),'b');
        legend([p21(1) p22(1)], 'Positive ticks','Negative Ticks');

        title(sprintf('%s: %d positive and %d negative', titleStr, np, nn));


        subplot(1,3,3)
        errorbar(index,coeffs,uncertainty);
        legend('Average Coefficients');
    end

    coeffs = coeffs(3:end);
    uncertainty = uncertainty(3:end);
else
    
    n = 0;
    coeffs = [];
    uncertainty = [];
end

if (n == 0)
    fprintf('estimateCoeffByTemp found 0 events for ''%s'' from %d to %d.\n', titleStr, minTemp, maxTemp);
    coeffs = [ 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0];
    uncertainty = [ 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0];
end

end

