function [Attitude,LocationData,logStruct,errorCode_Attitude,errorCode_Location] = getAttitude(time,logStruct,p)
%Current version takes an input of time in datetime format and outputs interpolated
%quaternions as well as satellite pointing direction to be applied to model
%magnetic field data.  Current version does not obtain yaw, pitch, roll
%Created by Robert Broadfoot 06/25/2019
%% Set path to locate desired files and type
pth = p.Results.attitudePath;
files = dir([pth '*.*']);
fid = 'not a file'; % placeholder to determine if desired file was located
errorCode_Attitude = 0;
tstart = time(1);
tend  = time(end);
nflag = 1;
start_index = 0;
stop_index = 0;

end_year_num = tend.Year - tstart.Year;
end_month_num = tend.Month - tstart.Month;
if end_year_num ~=0
    j = (end_year_num*12)+end_month_num;
    nflag = 2;
end
if end_year_num == 0 && end_month_num ~= 0
    j = end_month_num;
    nflag = 2;
end
%% Select Case for file search
switch(nflag)
    case 1 %Times start and end same month
%% Locating File        
    for i = 1:length(files)
        strf = files(i).name;
        pat = '(\w{8})_(\w{8})_(\w{11})_(\d{4})_(\d{2})';
        tokens= regexp( sprintf('%s,', strf),pat, 'tokens' ); 
        if ~isempty(tokens)
            yearstart = str2num(tokens{1,1}{1,4});
            monthstart = str2num(tokens{1,1}{1,5});
            if isequal(yearstart,tstart.Year)==1 && isequal(monthstart,tstart.Month)==1
                fid = files(i).name;
                break
            end
        end
    end
%% Determine file(s) exist(s)
    ttlpth = strcat(pth,fid);
    if isfile(ttlpth) == 0   
    errorCode_Attitude = -1;
    logStruct = mgfLog(logStruct,sprintf('Attitude data for the requested date and time between: %s and %s was not found. TERMINATING \n', t_fit(1), t_fit(end)),'error');
    mgfLogDump(logStruct);    
    return
    else
    fdata = fopen([pth,fid],'r+');
    fmt = '%d-%d-%d %d:%d:%f %f %f %f %f %d %f %f %f';
    datafi = textscan(fdata,fmt);
    fclose(fdata);
    end
%% Locate desired dates and times in file
filedat.Time = datetime([datafi{1,1} datafi{1,2} datafi{1,3} datafi{1,4} datafi{1,5} datafi{1,6}]);
filedat.Quaternion(:,1)=datafi{1,7};
filedat.Quaternion(:,2)=datafi{1,8};
filedat.Quaternion(:,3)=datafi{1,9};
filedat.Quaternion(:,4)=datafi{1,10};
filedat.Exclusion = [datafi{1,12}];
for s=1:numel(filedat.Time)
    if filedat.Time(s).Day == tstart.Day && filedat.Time(s).Hour == tstart.Hour &&...
            filedat.Time(s).Minute == tstart.Minute&&filedat.Time(s).Second == floor(tstart.Second)
       start_index = s;
    end
    if filedat.Time(s).Day == tend.Day && filedat.Time(s).Hour == tend.Hour &&...
            filedat.Time(s).Minute == tend.Minute&&ge(filedat.Time(s).Second,tend.Second)
       stop_index = s;
       break
    end
end
if filedat.Exclusion(start_index) > 60
    while filedat.Exclusion(start_index) > 60
        start_index = start_index - 1;
    end
end
if filedat.Exclusion(stop_index) > 60
    while filedat.Exclusion(stop_index) > 60
        stop_index = stop_index + 1;
    end
end


Attitude_initial.Time = filedat.Time(start_index:stop_index);
Attitude_initial.Quaternion(:,1) = filedat.Quaternion(start_index:stop_index,1);
Attitude_initial.Quaternion(:,2) = filedat.Quaternion(start_index:stop_index,2);
Attitude_initial.Quaternion(:,3) = filedat.Quaternion(start_index:stop_index,3);
Attitude_initial.Quaternion(:,4) = filedat.Quaternion(start_index:stop_index,4);
Attitude_initial.Exclusion = filedat.Exclusion(start_index:stop_index);
vec = find(Attitude_initial.Exclusion > 60);
if numel(vec) ~=0
    for x = length(vec):-1:1
    Attitude_initial.Time(vec(x)) = [];
    Attitude_initial.Quaternion(vec(x),:) = [];
    Attitude_initial.Exclusion(vec(x)) = [];
    end
end

     case 2 %Data ends in different file
         %% Needs to be implemented still
% %% Locating File(s)
%     for i = 1:length(files)
%         strf = files(i).name;
%         pat = '(\w{8})_(\w{8})_(\w{11})_(\d{4})_(\d{2})';
%         tokens= regexp( sprintf('%s,', strf),pat, 'tokens' ); 
%         if ~isempty(tokens)
%             yearstart = str2num(tokens{1,1}{1,4});
%             monthstart = str2num(tokens{1,1}{1,5});
%             if isequal(yearstart,tstart.Year)==1 && isequal(monthstart,tstart.Month)==1
%                 for k = 1:1+j
%                 fid(k) = files(k).name;
%                 end
%                 break
%             end
%         end
%     end
% %% Determine file(s) exist(s)
%     for s = 1:numel(fid)
%       ttlpth = strcat(pth,fid(s));
%       if isfile(ttlpth) == 0   
%         warningMessage = sprintf('Data for the requested date and time between:\n%s and %s was not found.', tstart, tend);
%         uiwait(msgbox(warningMessage));
%       end
%     end 
% %% Write data to structure for processing    
%     fdata = fopen([pth,fid(1)],'r+');
%     while ~feof(fdata)        
%         dataline = fgetl(fdata);
%         fmt = '%d-%d-%d %d:%d:%f %f %f %f %f %d %f %f %f';
%         current_data = textscan(dataline,fmt);
%         if ge(current_data{3},tstart.Day)&&ge(current_data{4},tstart.Hour)&&...
%                 ge(current_data{5},tstart.Minute)&&ge(current_data{6},tstart.Second)&&...
%                 le(current_data{11},60)
%             if linecount == 1 && current_data{6}>tstart.Second
%                 Attitude_initial.Time(linecount,:) = datetime([previous_data{1} previous_data{2} previous_data{3}...
%                     previous_data{4} previous_data{5} previous_data{6}]);
%                 Attitude_initial.Quaternion(linecount,:) = [previous_data{7} previous_data{8}...
%                     previous_data{9} previous_data{10}];
%                 linecount = linecount+1;
%             else   
%                 Attitude_initial.Time(linecount,:) = datetime([current_data{1} current_data{2} current_data{3}...
%                     current_data{4} current_data{5} current_data{6}]);
%                 Attitude_initial.Quaternion(linecount,:) = [current_data{7} current_data{8}...
%                     current_data{9} current_data{10}];
%                 linecount = linecount+1;
%             end
%         else
%             previous_data = current_data;
%         end
%     end
%     fclose(fdata);
%     if j > 2
%         for j = 2:numel(fid-1)
%           fdata = fopen([pth,fid(j)],'r+');  
%           while ~feof(fdata)        
%             dataline = fgetl(fdata);
%             fmt = '%d-%d-%d %d:%d:%f %f %f %f %f %d %f %f %f';
%             current_data = textscan(dataline,fmt);
%             if le(current_data{11},60)
%                 Attitude_initial.Time(linecount,:) = datetime([current_data{1} current_data{2} current_data{3}...
%                     current_data{4} current_data{5} current_data{6}]);
%                 Attitude_initial.Quaternion(linecount,:) = [current_data{7} current_data{8}...
%                     current_data{9} current_data{10}];
%                 linecount = linecount+1;
%             end
%           end
%           fclose(fdata);
%         end
%         fdata = fopen([pth,fid(end)],'r+');
%         while ~feof(fdata)        
%             dataline = fgetl(fdata);
%             fmt = '%d-%d-%d %d:%d:%f %f %f %f %f %d %f %f %f';
%             current_data = textscan(dataline,fmt);
%             if le(current_data{3},tend.Day)&&le(current_data{4},tend.Hour)&&...
%                     le(current_data{5},tend.Minute)&&le(current_data{11},60)
%                 if current_data{3}==tend.Day&&current_data{4}==tend.Hour&&current_data{5}==tend.Minute&&...
%                     ge(tend.Second,current_data{6})
%                     Attitude_initial.Time(linecount,:) = datetime([current_data{1} current_data{2} current_data{3}...
%                         current_data{4} current_data{5} current_data{6}]);
%                     Attitude_initial.Quaternion(linecount,:) = [current_data{7} current_data{8}...
%                         current_data{9} current_data{10}];
%                     fclose(fdata);
%                     break
%                 else
%                     Attitude_initial.Time(linecount,:) = datetime([current_data{1} current_data{2} current_data{3}...
%                         current_data{4} current_data{5} current_data{6}]);
%                     Attitude_initial.Quaternion(linecount,:) = [current_data{7} current_data{8}...
%                         current_data{9} current_data{10}];
%                     linecount = linecount+1;                    
%                 end
%             end
%         end
%     else
%         fdata = fopen([pth,fid(end)],'r+');
%         while ~feof(fdata)        
%             dataline = fgetl(fdata);
%             fmt = '%d-%d-%d %d:%d:%f %f %f %f %f %d %f %f %f';
%             current_data = textscan(dataline,fmt);
%             if le(current_data{3},tend.Day)&&le(current_data{4},tend.Hour)&&...
%                     le(current_data{5},tend.Minute)&&le(current_data{11},60)
%                 if current_data{3}==tend.Day&&current_data{4}==tend.Hour&&current_data{5}==tend.Minute&&...
%                     ge(tend.Second,current_data{6})
%                     Attitude_initial.Time(linecount,:) = datetime([current_data{1} current_data{2} current_data{3}...
%                         current_data{4} current_data{5} current_data{6}]);
%                     Attitude_initial.Quaternion(linecount,:) = [current_data{7} current_data{8}...
%                         current_data{9} current_data{10}];
%                     fclose(fdata);
%                     break
%                 else
%                     Attitude_initial.Time(linecount,:) = datetime([current_data{1} current_data{2} current_data{3}...
%                         current_data{4} current_data{5} current_data{6}]);
%                     Attitude_initial.Quaternion(linecount,:) = [current_data{7} current_data{8}...
%                         current_data{9} current_data{10}];
%                     linecount = linecount+1;                    
%                 end
%             end
%         end
%     end
% end
%     Attitude_initial = getadcs(time);
    
end
qi = slerp_quaternion(Attitude_initial,time);
[LocationData,logStruct,errorCode_Location] = getLocationpar(time,logStruct,p);
if errorCode_Location ~=0
    
    return
end
Pos = LocationData.Pos;
Vel = LocationData.Vel;
parfor m = 1:numel(time)
     qv = qi(m,:);
     qv = [qv(1) -qv(2) -qv(3) -qv(4)];
     qv= qv/norm(qv);
     qvm = [qv(1) -qv(2) -qv(3) -qv(4)];    
     qv2 = [qvm;qv(2) qv(1) -qv(4) qv(3);qv(3) qv(4) qv(1) -qv(2);qv(4) -qv(3) qv(2) qv(1)];
    Z = -Pos(m,:);
    Z = Z/norm(Z);
    V = Vel(m,:);
    V = V/norm(V);
    Y = cross(Z,V);
    Y = Y/norm(Y);
    X = cross(Y,Z);
    X = X/norm(X);
    Zq = [0,Z];
    Yq = [0,Y];
    Xq = [0,X];
    M = [1 0 0 0;Xq;Yq;Zq]; 
    qvn = qv2*M
    qvn = qvn/norm(qvn);
    qmat = [(qvn(1)^2)+(qvn(2)^2)-(qvn(3)^2)-(qvn(4)^2) 2*qvn(2)*qvn(3)-2*qvn(1)*qvn(4) 2*(qvn(1)*qvn(3)+qvn(2)*qvn(4));...
         2*(qvn(1)*qvn(4)+qvn(2)*qvn(3)) qvn(1)^2-qvn(2)^2+qvn(3)^2-qvn(4)^2 2*(qvn(3)*qvn(4)-qvn(1)*qvn(2));...
         2*(qvn(2)*qvn(4)-qvn(1)*qvn(3)) 2*(qvn(3)*qvn(4)+qvn(1)*qvn(2)) qvn(1)^2-qvn(2)^2-qvn(3)^2+qvn(4)^2]
    A = qmat';
    satX(m,:) = A(:,1);
    satY(m,:) = A(:,2);
    satZ(m,:) = A(:,3);
end
Attitude.Quaternion = qi;
Attitude.satX = satX;
Attitude.satY = satY;
Attitude.satZ = satZ;

end

