function [LocationData,logStruct,errorCode_Location] = getLocationpar(time,logStruct,p)
% This function takes a matlab datetime input in the form of [yyyy mm dd hh
% mm ss] and returns the geocentric latitude, longitude, and altitude for that
% given time.  
% 
%The filename format for the .mat file should be the numerical 
%values with no spaces for: start year start month start day start hour start
%minute start second _ end year end month end day end hour end minute end 
%second, filling in a zero for any value less than ten with the year being four digits.   
%
%This function requires the IRBEM Library to run.  .
%
% 
% 
%Initial Version by Robert Broadfoot 05/08/2019
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Convert UTC to GPS for file search
% Currently only setup for 2017+ to accound for the 18 second difference
% between GPS and UTC
Otime = time; %In case of error message after GPS conversion and for lat/long calculation
tstart = time(1);
tend = time(end);
errorCode_Location = 0;
tstart.Second = floor(tstart.Second)+18; tend.Second = floor(tend.Second)+18;
if tstart.Second >= 60
    tstart.Minute = tstart.Minute+1;
    tstart.Second = tstart.Second - 60;
    if tstart.Minute >= 60
        tstart.Hour = tstart.Hour+1;
        tstart.Minute = tstart.Minute-60;
        if tstart.Hour >= 24
            tstart.Day = tstart.Day+1;
            tstart.Hour=tstart.Hour-24;
            if tstart.Month == 1||tstart.Month == 3||tstart.Month == 5||tstart.Month == 7||...
                    tstart.Month == 8||tstart.Month == 10
                if tstart.Day > 31
                    tstart.Month = tstart.Month+1;
                    tstart.day = tstart.day-30;
                end
            end
            if tstart.Month == 2
                if tstart.Day > 28
                    tstart.Month = tstart.Month+1;
                    tstart.Day = tstart.Day-27;
                end
            end
            if tstart.Month == 4||tstart.Month == 6||tstart.Month == 9||tstart.Month == 11
                if tstart.Day > 30
                    tstart.Month = tstart.Month+1;
                    tstart.day = tstart.day-29;
                end
            end
            if tstart.Month == 12
                if tstart.Day > 31
                    tstart.Year = tstart.Year+1;
                    tstart.Month = tstart.Month-11;
                    tstart.Day = tstart.day-30;
                end
            end
        end
    end
end
if tend.Second >= 60
    tend.Minute = tend.Minute+1;
    tend.Second = tend.Second - 60;
    if tend.Minute >= 60
        tend.Hour = tend.Hour+1;
        tend.Minute = tend.Minute-60;
        if tend.Hour >= 24
            tend.Day = tend.Day+1;
            tend.Hour=tend.Hour-24;
            if tend.Month == 1||tend.Month == 3||tend.Month == 5||tend.Month == 7||...
                    tend.Month == 8||tend.Month == 10
                if tend.Day > 31
                    tend.Month = tend.Month+1;
                    tend.day = tend.day-30;
                end
            end
            if tend.Month == 2
                if tend.Day > 28
                    tend.Month = tend.Month+1;
                    tend.Day = tend.Day-27;
                end
            end
            if tend.Month == 4||tend.Month == 6||tend.Month == 9||tend.Month == 11
                if tend.Day > 30
                    tend.Month = tend.Month+1;
                    tend.day = tend.day-29;
                end
            end
            if tend.Month == 12
                if tend.Day > 31
                    tend.Year = tend.Year+1;
                    tend.Month = tend.Month-11;
                    tend.Day = tend.day-30;
                end
            end
        end
    end
end
%% Set path to locate desired files and type
pth = p.Results.locationPath;
files = dir([pth '*.mat']);
fid = 'not a file'; % placeholder to determine if desired file was located
%% Locating file in directory
for i = 1:length(files)
    strf = files(i).name;
    pat = '(\d{4})(\d{2})(\d{2})(\d{2})(\d{2})(\d{2})_(\d{4})(\d{2})(\d{2})(\d{2})(\d{2})(\d{2}).([^,]+)';
    tokens= regexp( sprintf('%s,', strf),pat, 'tokens' ); 
    yearstart = str2num(tokens{1,1}{1,1});
    monthstart = str2num(tokens{1,1}{1,2});
    daystart = str2num(tokens{1,1}{1,3});
    hourstart = str2num(tokens{1,1}{1,4});
    yearend = str2num(tokens{1,1}{1,7});
    monthend = str2num(tokens{1,1}{1,8});
    dayend = str2num(tokens{1,1}{1,9});
    hourend = str2num(tokens{1,1}{1,10});
    minuteend = str2num(tokens{1,1}{1,11});
    secondend = str2num(tokens{1,1}{1,12});
    if yearstart==tstart.Year&&monthstart==tstart.Month&&abs(tstart.Day-daystart)==1 
        if le(tend.Day,dayend)
           fid = files(i).name;
           break
        else
           if monthend > tstart.Month
            fid = files(i).name;
            break
           else
            fid = files(i+1).name;
            break
           end
        end
    end  
end
%% Determine data for given time exists
ttlpth = strcat(pth,fid);
if isfile(ttlpth) == 0   
errorCode_Location = -1;  
logStruct = mgfLog(logStruct,sprintf('Location data for the requested date and time between: %s and %s was not found. TERMINATING \n', tstart, tend),'error');
mgfLogDump(logStruct);  
return
else
H = load([pth,fid]);
end
%% Advancing all times to GPS
if isfile(ttlpth) ~= 0
sprintf('Converting all times to gps time')
parfor s = 1:numel(time)
time(s).Second = time(s).Second+18;
if time(s).Second >= 60
    time(s).Minute = time(s).Minute+1;
    time(s).Second = time(s).Second - 60;
    if time(s).Minute >= 60
        time(s).Hour = time(s).Hour+1;
        time(s).Minute = time(s).Minute-60;
        if time(s).Hour >= 24
            time(s).Day = time(s).Day+1;
            time(s).Hour=time(s).Hour-24;
            if time(s).Month == 1||time(s).Month == 3||time(s).Month(s) == 5||time(s).Month == 7||...
                    time(s).Month == 8||time(s).Month == 10
                if time(s).Day > 31
                    time(s).Month = time(s).Month+1;
                    time(s).day = time(s).day-30;
                end
            end
            if time(s).Month == 2
                if time(s).Day > 28
                    time(s).Month = time(s).Month+1;
                    time(s).Day = time(s).Day-27;
                end
            end
            if time(s).Month == 4||time(s).Month == 6||time(s).Month == 9||time(s).Month == 11
                if time(s).Day > 30
                    time(s).Month = time(s).Month+1;
                    time(s).day = time(s).day-29;
                end
            end
            if time(s).Month == 12
                if time(s).Day > 31
                    time(s).Year = time(s).Year+1;
                    time(s).Month = time(s).Month-11;
                    time(s).Day = time(s).day-30;
                end
            end
        end
    end
end
end
   dtime2 = datetime(H.ORB.gps_date_time);
   XGEO = interp1(dtime2, H.ORB.pos(:,1) ,time,'spline');
   YGEO = interp1(dtime2, H.ORB.pos(:,2) ,time,'spline');
   ZGEO = interp1(dtime2, H.ORB.pos(:,3) ,time,'spline');
   VXGEO = interp1(dtime2, H.ORB.vel(:,1) ,time,'spline');
   VYGEO = interp1(dtime2, H.ORB.vel(:,2) ,time,'spline');
   VZGEO = interp1(dtime2, H.ORB.vel(:,3) ,time,'spline');
   LocationData.Time = Otime;
   LocationData.Pos  = onera_desp_lib_coord_trans([XGEO,YGEO,ZGEO],'geo2gei',Otime);
   LocationData.Vel  = onera_desp_lib_coord_trans([VXGEO,VYGEO,VZGEO],'geo2gei',Otime);
%% Finds geocentric height, latitude, longitude
   LocationData.ALL = onera_desp_lib_coord_trans([XGEO,YGEO,ZGEO],'geo2rll',Otime);
%% Finds maglat, maglonm mlt   
   MAG = onera_desp_lib_coord_trans(LocationData.Pos,'gei2mag',Otime);
   SPH = onera_desp_lib_coord_trans(MAG,'car2sph',Otime);
   maglat = SPH(:,2);
   maglon = SPH(:,3);
   ML = onera_desp_lib_coord_trans([1 0 0],'gsm2mag',Otime);
   MLS = onera_desp_lib_coord_trans(ML,'car2sph',Otime);
   mlt = (maglon-MLS(:,3)+180)/15;
%% Correcting for mlt rollovers   
   parfor j = 1:numel(mlt)
       if ge(mlt(j),24)
          mlt(j) = mlt(j)-24; 
       end
       if le(mlt(j),0)
          mlt(j) = mlt(j)+24;
       end
   end
   LocationData.MAG(:,1) = maglat;
   LocationData.MAG(:,2) = maglon;
   LocationData.MAG(:,3) = mlt;
%% Convert height to altitude based on WGS84 dimensions
a = 6378137; %semi-major axis
b = 6356752.314245; %semi-minor axis
R = sqrt(((a^2.*cosd(LocationData.ALL(:,2))).^2+(b.^2.*sind(LocationData.ALL(:,2))).^2)./((a.*cosd(LocationData.ALL(:,2))).^2+(b.*sind(LocationData.ALL(:,2))).^2)); % Equation for distance from center to point on spheroid
LocationData.ALL(:,1) = (LocationData.ALL(:,1) - R)./1000; %result in km
end
end
