function [] = mgf_Level1_par(fileName, p, logStruct)

defs = mgfDefs();
curLevel = 0;

%% Init the log infrastructure

if isempty(logStruct)
    logStruct = struct;
end

logStruct = mgfLogInit( logStruct, mfilename(), p, fileName, '', 'msg' );

[ retVal, tStart, tEnd, dataLevel, logStruct ] = mgfParseFilename( fileName, logStruct );

if retVal
   logStruct = mgfLog(logStruct, sprintf('mgfParseFilename returned %d.', retVal), 'error');
   mgfLogDump(logStruct);
   return;
end

fileID = fopen(fileName);
rawData = fread(fileID);
fclose(fileID);

maxPackets = ceil(numel(rawData)/defs.cPKTLEN);

lv0Packets(maxPackets) = struct('CCSDSTime', [], 'raw', []);

if (dataLevel == 0)
    logStruct = mgfLog(logStruct, 'Flight data - parsing for CCSDS timestamps and .lv0 packets.', 'info');
    numPackets = 0;
    i = 0;
    while (i < numel(rawData) - defs.cPKTLEN)
       i = i + 1;
       if ( (rawData(defs.cCCSDSLen+i+defs.oDLE) == defs.cDLE) && (rawData(defs.cCCSDSLen+i+defs.oSTX)==defs.cSTX) && (rawData(defs.cCCSDSLen+i+defs.oPID) == defs.cPID) && (256*rawData(defs.cCCSDSLen+i+defs.oLength)+rawData(defs.cCCSDSLen+i+defs.oLength+1) == defs.cPKTLEN) )
           numPackets = numPackets + 1;
           lv0Packets(numPackets).CCSDSTime = rawData(i:i+defs.cCCSDSLen-1);
           lv0Packets(numPackets).raw = rawData(i+defs.cCCSDSLen:i+defs.cCCSDSLen+defs.cPKTLEN-1);
           i = i + defs.cCCSDSLen + defs.cPKTLEN - 1;
       end    
    end
elseif (dataLevel == 99)
    logStruct = mgfLog(logStruct, 'Lab data - parsing for .lv0 packets only.', 'warn');
    numPackets = 0;
    i = 0;
    while (i < numel(rawData) - defs.cPKTLEN)
       i = i + 1;
       if ( (rawData(i+defs.oDLE) == defs.cDLE) && (rawData(i+defs.oSTX)==defs.cSTX) && (rawData(i+defs.oPID) == defs.cPID) && (256*rawData(i+defs.oLength)+rawData(i+defs.oLength+1) == defs.cPKTLEN) )
           numPackets = numPackets + 1;
           lv0Packets(numPackets).CCSDSTime = [];
           lv0Packets(numPackets).raw = rawData(i:i+defs.cPKTLEN-1);
           i = i + defs.cPKTLEN - 1;
       end    
    end
end

lv0Packets = lv0Packets(1:numPackets-1);

logStruct = mgfLog(logStruct, sprintf('Found %d valid .lv0 packets.\n', numPackets), 'info');

InboardPacket = repmat(defs.nullpacket,1,numel(lv0Packets));
OutboardPacket = repmat(defs.nullpacket,1,numel(lv0Packets));
InboardPacketCount = 0;
OutboardPacketCount = 0;

for i = 1:numel(lv0Packets)
    tempPacket = unpackLV0DatePacket( lv0Packets(i));

    if (tempPacket.BoardID == defs.cIDInboard)
        InboardPacketCount = InboardPacketCount + 1;
        InboardPacket(InboardPacketCount) = tempPacket;
    elseif (tempPacket.BoardID == defs.cIDOutboard)
        OutboardPacketCount = OutboardPacketCount + 1;
        OutboardPacket(OutboardPacketCount) = tempPacket;
    end
end

if (dataLevel == 99)
    stubDate = datetime(2000,01,01,00,00,00);
    
    logStruct = mgfLog(logStruct,sprintf('Stubbing date to %s for lab data.\n',stubDate), 'warn');
    
    for i = 1:numel(InboardPacket)
        InboardPacket(i).Time = stubDate + seconds(i);
    end
    
    for i = 1:numel(OutboardPacket)
        OutboardPacket(i).Time = stubDate + seconds(i);
    end
    
end

if ( (InboardPacketCount < 10) || (OutboardPacketCount < 10) )
    logStruct = mgfLog(logStruct,sprintf('Insufficient packets for sensible reconstruction.\n'), 'error');
    logStruct = mgfLog(logStruct,sprintf('Inboard had %d packets. Outboard had %d packets.\n', InboardPacketCount, OutboardPacketCount), 'error');
    logStruct = mgfLog(logStruct,sprintf('Abandoning file.\n'), 'error');
    mgfLogDump(logStruct);
    return;
end

InboardPacket = InboardPacket(1:InboardPacketCount);
OutboardPacket = OutboardPacket(1:OutboardPacketCount);

if ~exist('metadata', 'var')
    metadata = struct;
end

metadata.Level0 = struct;
metadata.Level0.StartTime =  min([InboardPacket(1).Time OutboardPacket(1).Time]);
metadata.Level0.EndTime =  max([InboardPacket(end).Time OutboardPacket(end).Time]);

outputFileName = genFileName( metadata.Level0.StartTime, metadata.Level0.EndTime, curLevel+1, defs.Version );

outputFileNameFull = strcat(p.Results.outputPath, filesep, outputFileName);

logStruct = mgfLog(logStruct, sprintf('Saving output file: %s\n', outputFileNameFull), 'info');

save(outputFileNameFull, 'InboardPacket', 'OutboardPacket', 'metadata', 'logStruct');

end

