function [] = mgf_Level2_par(fileName, p, logStruct_temp)
%UNTITLED Summary of this function goes here
%   Detailed explanation goes here

defs = mgfDefs();
curLevel = 1;

%% Init the log infrastructure

if isempty(logStruct_temp)
    logStruct_temp = struct;
end

logStruct_temp = mgfLogInit( logStruct_temp, mfilename(), p, fileName, '', 'msg' );

[ retVal, tStart, tEnd, dataLevel, logStruct_temp ] = mgfParseFilename( fileName, logStruct_temp );

if retVal
   logStruct_temp = mgfLog(logStruct_temp, sprintf('mgfParseFilename returned %d.', retVal), 'error');
   mgfLogDump(logStruct_temp);
   return;
end

load(fileName,'-mat');

logStruct.text = [logStruct.text logStruct_temp.text];
logStruct.fileName = logStruct_temp.fileName;
logStruct.callingFileName = logStruct_temp.callingFileName;
logStruct.level = logStruct_temp.level;

[ t_Inboard, magData_Inboard, t_hk_Inboard, hk_Inboard_aux, ppsOffsets_Inboard, logStruct, errorCode_Inboard ] = unRollPackets( InboardPacket, logStruct );
[ t_Outboard, magData_Outboard, t_hk_Outboard, hk_Outboard_aux, ppsOffsets_Outboard, logStruct, errorCode_Outboard ] = unRollPackets( OutboardPacket, logStruct );

if ( errorCode_Inboard ~= 0)
    logStruct = mgfLog(logStruct, sprintf('Inboard unRollPackets returned error code %d. TERMINATING.\n', errorCode_Inboard), 'error');
    mgfLogDump(logStruct);
    return;
end

if ( errorCode_Outboard ~= 0)
    logStruct = mgfLog(logStruct, sprintf('ERROR: Outboard unRollPackets returned error code %d. TERMINATING.\n', errorCode_Outboard), 'error');
    mgfLogDump(logStruct);
    return;
end


%% Determine Master/Slave

ms_Inboard = hk_Inboard_aux(isfinite(hk_Inboard_aux(:,1)),1);
ms_Outboard = hk_Outboard_aux(isfinite(hk_Outboard_aux(:,1)),1);

if ~all(ms_Inboard(1) == ms_Inboard)
    logStruct = mgfLog(logStruct, sprintf('Inboard Master/Slave status is internally inconsistent.\n'), 'error');
    mgfLogDump(logStruct);
    return;
elseif ~all(ms_Outboard(1) == ms_Outboard)
    logStruct = mgfLog(logStruct, sprintf('Outboard Master/Slave status is internally inconsistent.\n'), 'error');
    mgfLogDump(logStruct);
    return;
elseif (ms_Outboard(1) == 0 && ms_Inboard(1) == 255)
    logStruct = mgfLog(logStruct, sprintf('Outboard is MASTER. Inboard is SLAVE.\n'), 'info');
    ms_Outboard = 'Master';
    ms_Inboard = 'Slave';
elseif (ms_Outboard(1) == 255 && ms_Inboard(1) == 0)
    logStruct = mgfLog(logStruct, sprintf('Outboard is SLAVE. Inboard is MASTER.\n'), 'info');
    ms_Outboard = 'Slave';
    ms_Inboard = 'Master';
else
    logStruct = mgfLog(logStruct, sprintf('Inboard Master/Slave was mutually inconsistent.\n'), 'error');
    mgfLogDump(logStruct);
    return;
end

    

%% Determine version numbers

version_Inboard_temp = vertcat(InboardPacket.Version);
version_Outboard_temp = vertcat(OutboardPacket.Version);

version_Inboard_temp = version_Inboard_temp(isfinite(version_Inboard_temp(:,1)) & isfinite(version_Inboard_temp(:,2)) & isfinite(version_Inboard_temp(:,3)),:);
version_Outboard_temp = version_Outboard_temp(isfinite(version_Outboard_temp(:,1)) & isfinite(version_Outboard_temp(:,2)) & isfinite(version_Outboard_temp(:,3)),:);

if ~all(all(version_Inboard_temp(1,:) == version_Inboard_temp))
    logStruct = mgfLog(logStruct, sprintf('Inboard version is not internally consistent.\n'), 'error');
    mgfLogDump(logStruct);
    return;
else
    version_Inboard = version_Inboard_temp(1,:);
    logStruct = mgfLog(logStruct, sprintf('Inboard version reported as %d.%d.%d\n', version_Inboard(1), version_Inboard(2), version_Inboard(3) ), 'info'); 
end


if ~all(all(version_Outboard_temp(1,:) == version_Outboard_temp))
    logStruct = mgfLog( logStruct, sprintf('Outboard version is not internally consistent.\n'), 'error');
    mgfLogDump(logStruct);
    return;
else
    version_Outboard = version_Outboard_temp(1,:);
    logStruct = mgfLog( logStruct, sprintf('Outboard version reported as %d.%d.%d\n', version_Outboard(1), version_Outboard(2), version_Outboard(3) ), 'info'); 
end


%% Account for master/slave transmission offset

% ** Alignment of the data

% * The master and slave share a communication packet so the slave has to
% transmit 62.5 ms after the master. This delay JUST reflects the
% communication chanel.

if (strcmp(ms_Outboard,'Master') && strcmp(ms_Inboard,'Slave') )
    t_Inboard = t_Inboard - seconds(0.0625);
    t_hk_Inboard = t_hk_Inboard - seconds(0.0625);
elseif (strcmp(ms_Outboard,'Slave') && strcmp(ms_Inboard,'Master') )
    t_Inboard = t_Inboard - seconds(0.0625);
    t_hk_Inboard = t_hk_Inboard - seconds(0.0625);
else
    logStruct = mgfLog(logStruct, sprintf('Should never get here. (Account for master/slave transmission offset).\n'), 'error');
    mgfLogDump(logStruct);
    return;
end

%% Confirm duplicate values in the housekeeping are, in fact, duplicate
% aux 1-20 should equal aux 21-40

if ~all(all(hk_Inboard_aux(all(transpose(isfinite(hk_Inboard_aux(:,:)))),1:20) ...
        == hk_Inboard_aux(all(transpose(isfinite(hk_Inboard_aux(:,:)))),21:40)))
    logStruct = mgfLog(logStruct, sprintf('Inboard duplicate aux data is NOT duplicate.\n'), 'error');
    mgfLogDump(logStruct);
    return
end

if ~all(all(hk_Outboard_aux(all(transpose(isfinite(hk_Outboard_aux(:,:)))),1:20) ...
        == hk_Outboard_aux(all(transpose(isfinite(hk_Outboard_aux(:,:)))),21:40)))
    logStruct = mgfLog(logStruct, sprintf('Outboard duplicate aux data is NOT duplicate.\n'), 'error');
    mgfLogDump(logStruct);
    return
end


%% Compare duplicate ADC/DAC values in housekeeping to those in the data
% Do this before we start fiddling with timeseries alignment.

if ( ~all(bitsrl(bitand(int16(magData_Inboard(1:160:end,1)),hex2dec('0f00')),8) ==  hk_Inboard_aux(:,9) | isnan(magData_Inboard(1:160:end,1)) | isnan(hk_Inboard_aux(:,9))) || ...
        ~all(bitand(int16(magData_Inboard(1:160:end,1)),hex2dec('00ff')) ==  hk_Inboard_aux(:,10) | isnan(magData_Inboard(1:160:end,1)) | isnan(hk_Inboard_aux(:,10))) || ...
        ~all(bitsrl(bitand(int16(magData_Inboard(1:160:end,2)),hex2dec('0f00')),8) ==  hk_Inboard_aux(:,11) | isnan(magData_Inboard(1:160:end,2)) | isnan(hk_Inboard_aux(:,11))) || ...
        ~all(bitand(int16(magData_Inboard(1:160:end,2)),hex2dec('00ff')) ==  hk_Inboard_aux(:,12) | isnan(magData_Inboard(1:160:end,2)) | isnan(hk_Inboard_aux(:,12))) || ...
        ~all(bitsrl(bitand(int16(magData_Inboard(1:160:end,3)),hex2dec('0f00')),8) ==  hk_Inboard_aux(:,13) | isnan(magData_Inboard(1:160:end,3)) | isnan(hk_Inboard_aux(:,13))) || ...
        ~all(bitand(int16(magData_Inboard(1:160:end,3)),hex2dec('00ff')) ==  hk_Inboard_aux(:,14) | isnan(magData_Inboard(1:160:end,3)) | isnan(hk_Inboard_aux(:,14))) || ...
        ~all(bitsrl(bitand(int16(magData_Inboard(1:160:end,4)),hex2dec('0f00')),8) ==  hk_Inboard_aux(:,15) | isnan(magData_Inboard(1:160:end,4)) | isnan(hk_Inboard_aux(:,15))) || ...
        ~all(bitand(int16(magData_Inboard(1:160:end,4)),hex2dec('00ff')) ==  hk_Inboard_aux(:,16) | isnan(magData_Inboard(1:160:end,4)) | isnan(hk_Inboard_aux(:,16))) || ...
        ~all(bitsrl(bitand(int16(magData_Inboard(1:160:end,5)),hex2dec('0f00')),8) ==  hk_Inboard_aux(:,17) | isnan(magData_Inboard(1:160:end,5)) | isnan(hk_Inboard_aux(:,17))) || ...
        ~all(bitand(int16(magData_Inboard(1:160:end,5)),hex2dec('00ff')) ==  hk_Inboard_aux(:,18) | isnan(magData_Inboard(1:160:end,5)) | isnan(hk_Inboard_aux(:,18))) || ...
        ~all(bitsrl(bitand(int16(magData_Inboard(1:160:end,6)),hex2dec('0f00')),8) ==  hk_Inboard_aux(:,19) | isnan(magData_Inboard(1:160:end,6)) | isnan(hk_Inboard_aux(:,19))) || ...
        ~all(bitand(int16(magData_Inboard(1:160:end,6)),hex2dec('00ff')) ==  hk_Inboard_aux(:,20) | isnan(magData_Inboard(1:160:end,6)) | isnan(hk_Inboard_aux(:,20))) )
    logStruct = mgfLog(logStruct, sprintf('ADC/DAC values in Inboard housekeeping didnt match data stream'),'warn');
end

if ( ~all(bitsrl(bitand(int16(magData_Outboard(1:160:end,1)),hex2dec('0f00')),8) ==  hk_Outboard_aux(:,9) | isnan(magData_Outboard(1:160:end,1)) | isnan(hk_Outboard_aux(:,9))) || ...
        ~all(bitand(int16(magData_Outboard(1:160:end,1)),hex2dec('00ff')) ==  hk_Outboard_aux(:,10) | isnan(magData_Outboard(1:160:end,1)) | isnan(hk_Outboard_aux(:,10))) || ...
        ~all(bitsrl(bitand(int16(magData_Outboard(1:160:end,2)),hex2dec('0f00')),8) ==  hk_Outboard_aux(:,11) | isnan(magData_Outboard(1:160:end,2)) | isnan(hk_Outboard_aux(:,11))) || ...
        ~all(bitand(int16(magData_Outboard(1:160:end,2)),hex2dec('00ff')) ==  hk_Outboard_aux(:,12) | isnan(magData_Outboard(1:160:end,2)) | isnan(hk_Outboard_aux(:,12))) || ...
        ~all(bitsrl(bitand(int16(magData_Outboard(1:160:end,3)),hex2dec('0f00')),8) ==  hk_Outboard_aux(:,13) | isnan(magData_Outboard(1:160:end,3)) | isnan(hk_Outboard_aux(:,13))) || ...
        ~all(bitand(int16(magData_Outboard(1:160:end,3)),hex2dec('00ff')) ==  hk_Outboard_aux(:,14) | isnan(magData_Outboard(1:160:end,3)) | isnan(hk_Outboard_aux(:,14))) || ...
        ~all(bitsrl(bitand(int16(magData_Outboard(1:160:end,4)),hex2dec('0f00')),8) ==  hk_Outboard_aux(:,15) | isnan(magData_Outboard(1:160:end,4)) | isnan(hk_Outboard_aux(:,15))) || ...
        ~all(bitand(int16(magData_Outboard(1:160:end,4)),hex2dec('00ff')) ==  hk_Outboard_aux(:,16) | isnan(magData_Outboard(1:160:end,4)) | isnan(hk_Outboard_aux(:,16))) || ...
        ~all(bitsrl(bitand(int16(magData_Outboard(1:160:end,5)),hex2dec('0f00')),8) ==  hk_Outboard_aux(:,17) | isnan(magData_Outboard(1:160:end,5)) | isnan(hk_Outboard_aux(:,17))) || ...
        ~all(bitand(int16(magData_Outboard(1:160:end,5)),hex2dec('00ff')) ==  hk_Outboard_aux(:,18) | isnan(magData_Outboard(1:160:end,5)) | isnan(hk_Outboard_aux(:,18))) || ...
        ~all(bitsrl(bitand(int16(magData_Outboard(1:160:end,6)),hex2dec('0f00')),8) ==  hk_Outboard_aux(:,19) | isnan(magData_Outboard(1:160:end,6)) | isnan(hk_Outboard_aux(:,19))) || ...
        ~all(bitand(int16(magData_Outboard(1:160:end,6)),hex2dec('00ff')) ==  hk_Outboard_aux(:,20) | isnan(magData_Outboard(1:160:end,6)) | isnan(hk_Outboard_aux(:,20))) )
    logStruct = mgfLog(logStruct, sprintf('ADC/DAC values in Outboard housekeeping didnt match data stream'),'warn');
end



%% Align inboard and outboard streams


% * Use the CCSDS timestamps to align the packets (i.e., 1 second
% granularity)
%[ offsets ] = timeArryOffsets( t_Inboard, t_Outboard );

t_Inboard_finite = t_Inboard(~isnat(t_Inboard));
t_Inboard_first = t_Inboard_finite(1);
t_Inboard_first_loc = find(t_Inboard == t_Inboard_first);

t_Outboard_finite = t_Outboard(~isnat(t_Outboard));
t_Outboard_first = t_Outboard_finite(1);
t_Outboard_first_loc = find(t_Outboard == t_Outboard_first);

offset_sec = seconds(t_Inboard_first - t_Outboard_first);
offset_loc = t_Inboard_first_loc - t_Outboard_first_loc;

offset = round(160*offset_sec);

if (offset > 1) 
    t_Inboard = [NaT(abs(offset),1); t_Inboard];
    magData_Inboard = [nan(abs(offset),6); magData_Inboard];
end

if (offset < 1)
    t_Outboard = [NaT(abs(offset),1); t_Outboard];
    magData_Outboard = [nan(abs(offset),6); magData_Outboard];
end

maxLen = max([numel(t_Inboard) numel(t_Outboard) ]);

if ( numel(t_Inboard) < maxLen)
    magData_Inboard = [ magData_Inboard; nan(abs(maxLen - numel(t_Inboard)),6) ];
    t_Inboard = [ t_Inboard; NaT(maxLen - numel(t_Inboard),1)];
end

if ( numel(t_Outboard) < maxLen)
    magData_Outboard = [ magData_Outboard; nan(abs(maxLen - numel(t_Outboard)),6) ];
    t_Outboard = [ t_Outboard; NaT(maxLen - numel(t_Outboard),1) ];
end



if (offset_sec > 1) 
    t_hk_Inboard = [NaT(abs(round(offset_sec)),1); t_hk_Inboard];
    hk_Inboard_aux = [nan(abs(round(offset_sec)),40); hk_Inboard_aux];
end

if (offset_sec < 1)
    t_hk_Outboard = [NaT(abs(round(offset_sec)),1); t_hk_Outboard];
    hk_Outboard_aux = [nan(abs(round(offset_sec)),40); hk_Outboard_aux];
end

hkmaxLen = max([numel(t_hk_Inboard) numel(t_hk_Outboard) ]);

if ( numel(t_hk_Inboard) < hkmaxLen)
    hk_Inboard_aux = [hk_Inboard_aux; nan(abs(hkmaxLen - numel(hk_Inboard_aux(:,1))),40) ];
    t_hk_Inboard = [ t_hk_Inboard; NaT(hkmaxLen - numel(t_hk_Inboard),1)];
    end

if ( numel(t_hk_Outboard) < hkmaxLen)
    hk_Outboard_aux = [hk_Outboard_aux; nan(abs(hkmaxLen - numel(hk_Outboard_aux(:,1))),40) ];
    t_hk_Outboard = [ t_hk_Outboard; NaT(hkmaxLen - numel(t_hk_Outboard),1) ];
end


%% Create common time index

if ( sum(isfinite(t_Inboard)) < 5 )
    logStruct = mgfLog(logStruct, sprintf('Insufficient finite timestamps in Inboard data.\n'), 'error');
    mgfLogDump(logStruct);
    return;
end

if ( sum(isfinite(t_Outboard)) < 5 )
    logStruct = mgfLog(logStruct, sprintf('Insufficient finite timestamps in Outboard data.\n'), 'error');
    mgfLogDump(logStruct);
    return;
end


t_index = transpose(1:maxLen);
b = robustfit([t_index; t_index], datenum([t_Inboard; t_Outboard]));
t_fit = datetime(b(1)+b(2)*t_index, 'ConvertFrom','datenum');

tFitLim = 0.003; % FIXME - move to definitions?
t_Outboard_diff = t_Outboard - t_fit;
t_Outboard_diff_worst = max(seconds(t_Outboard_diff(~isnan(t_Outboard_diff))));
if (t_Outboard_diff_worst > tFitLim)
    logStruct = mgfLog(logStruct, sprintf('Outboard had a worst case fit %0.3f worst than threshold (%0.3f).\n', t_Outboard_diff_worst, tFitLim), 'error');
    mgfLogDump(logStruct);
    return
end

t_Inboard_diff = t_Inboard - t_fit;
t_Inboard_diff_worst = max(seconds(t_Inboard_diff(~isnan(t_Inboard_diff))));
if (t_Inboard_diff_worst > tFitLim)
    logStruct = mgfLog(logStruct, sprintf('Inboard had a worst case fit %0.3f worst than threshold (%0.3f).\n', t_Inboard_diff_worst, tFitLim), 'error');
    mgfLogDump(logStruct);
    return
end

t_hk_index = transpose(1:hkmaxLen);
b_hk = robustfit([t_hk_index; t_hk_index], datenum([t_hk_Inboard; t_hk_Outboard]));
t_hk = datetime(b_hk(1)+b_hk(2)*t_hk_index, 'ConvertFrom','datenum');

%% Housekeeping data

%% FIXME - move to definitions.
VMON1SCALEOutboard    =  0.004978;
VMON1OFFSETOutboard   =  1.63793;
VMON2SCALEOutboard    =  0.010517;
VMON2OFFSETOutboard   = -7.30899;
TSENSORSCALEOutboard  = -0.249337;
TSENSOROFFSETOutboard =  162.020;
TEBOXSCALEOutboard    = -0.265365;
TEBOXOFFSETOutboard   =  165.088;
VMON1SCALEInboard     =  0.004978;
VMON1OFFSETInboard    =  1.63793;
VMON2SCALEInboard     =  0.010517;
VMON2OFFSETInboard    = -7.30899;
TSENSORSCALEInboard   = -0.257595;
TSENSOROFFSETInboard  =  160.268;
TEBOXSCALEInboard     = -0.261199;
TEBOXOFFSETInboard    =  164.497;

%% Reconstruct housekeeping voltages and temperatures.  

hk_Inboard                  = struct;
hk_Inboard.magNum           = hk_Inboard_aux(:,1);
hk_Inboard.statusFlags      = hk_Inboard_aux(:,2);
hk_Inboard.bitChk           = hk_Inboard_aux(:,3);
hk_Inboard.onHzFlag         = hk_Inboard_aux(:,4);
hk_Inboard.Vmon1            = VMON1SCALEInboard*hk_Inboard_aux(:,5) + VMON1OFFSETInboard;
hk_Inboard.Vmon2            = VMON2SCALEInboard*hk_Inboard_aux(:,6) + VMON2OFFSETInboard;
hk_Inboard.Tsensor          = TSENSORSCALEInboard*hk_Inboard_aux(:,7) + TSENSOROFFSETInboard;
hk_Inboard.Tebox            = TEBOXSCALEInboard*hk_Inboard_aux(:,8) + TEBOXOFFSETInboard;

hk_Outboard                  = struct;
hk_Outboard.magNum           = hk_Outboard_aux(:,1);
hk_Outboard.statusFlags      = hk_Outboard_aux(:,2);
hk_Outboard.bitChk           = hk_Outboard_aux(:,3);
hk_Outboard.onHzFlag         = hk_Outboard_aux(:,4);
hk_Outboard.Vmon1            = VMON1SCALEOutboard*hk_Outboard_aux(:,5) + VMON1OFFSETOutboard;
hk_Outboard.Vmon2            = VMON2SCALEOutboard*hk_Outboard_aux(:,6) + VMON2OFFSETOutboard;
hk_Outboard.Tsensor          = TSENSORSCALEOutboard*hk_Outboard_aux(:,7) + TSENSOROFFSETOutboard;
hk_Outboard.Tebox            = TEBOXSCALEOutboard*hk_Outboard_aux(:,8) + TEBOXOFFSETOutboard;

%% FIXME STOPPED HERE.

%% NAN data where ADC is clipped

magData_Inboard( ((magData_Inboard(:,4) == -2048) | (magData_Inboard(:,4) == 2047)), 4) = nan;
magData_Inboard( ((magData_Inboard(:,5) == -2048) | (magData_Inboard(:,5) == 2047)), 5) = nan;
magData_Inboard( ((magData_Inboard(:,6) == -2048) | (magData_Inboard(:,6) == 2047)), 6) = nan;

magData_Outboard( ((magData_Outboard(:,4) == -2048) | (magData_Outboard(:,4) == 2047)), 4) = nan;
magData_Outboard( ((magData_Outboard(:,5) == -2048) | (magData_Outboard(:,5) == 2047)), 5) = nan;
magData_Outboard( ((magData_Outboard(:,6) == -2048) | (magData_Outboard(:,6) == 2047)), 6) = nan;

%% Offsets for DAC updates

if ( (version_Inboard(1) >= 1) & (version_Inboard(2) >= 3) & (version_Inboard >= 0) )
    logStruct = mgfLog(logStruct, sprintf('Nudging Inboard DAC updates (firmware >= 1.3.0)\n'), 'info');
    indInbX = ( magData_Inboard(1:end-1,1) ~= magData_Inboard(2:end,1) );
    magData_Inboard([indInbX; false], 1) = magData_Inboard([false; indInbX],1);
end

if ( (version_Outboard(1) >= 1) & (version_Outboard(2) >= 3) & (version_Outboard >= 0) )
    logStruct = mgfLog(logStruct, sprintf('Nudging Outboard DAC updates (firmware >= 1.3.0)\n'), 'info');
    indOutbX = ( magData_Outboard(1:end-1,1) ~= magData_Outboard(2:end,1) );
    magData_Outboard([indOutbX; false], 1) = magData_Outboard([false; indOutbX],1);
end

%% Check if we need to extract DAC Ticks

if (p.Results.extractTicks)
    
    ticks = struct;
    
    fprintf('Ready to extract ticks.\n');
    [ticks.INXXP2] = getTicks(magData_Inboard(:,1), magData_Inboard(:,4), magData_Inboard(:,2), magData_Inboard(:,3), 2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INXXP2');
    [ticks.INXYP2] = getTicks(magData_Inboard(:,1), magData_Inboard(:,5), magData_Inboard(:,2), magData_Inboard(:,3), 2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INXYP2');
    [ticks.INXZP2] = getTicks(magData_Inboard(:,1), magData_Inboard(:,6), magData_Inboard(:,2), magData_Inboard(:,3), 2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INXZP2');
    
    [ticks.INYXP2] = getTicks(magData_Inboard(:,2), magData_Inboard(:,4), magData_Inboard(:,1), magData_Inboard(:,3), 2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INYXP2');
    [ticks.INYYP2] = getTicks(magData_Inboard(:,2), magData_Inboard(:,5), magData_Inboard(:,1), magData_Inboard(:,3), 2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INYYP2');
    [ticks.INYZP2] = getTicks(magData_Inboard(:,2), magData_Inboard(:,6), magData_Inboard(:,1), magData_Inboard(:,3), 2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INYZP2');
    
    [ticks.INZXP2] = getTicks(magData_Inboard(:,3), magData_Inboard(:,4), magData_Inboard(:,1), magData_Inboard(:,2), 2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INZXP2');
    [ticks.INZYP2] = getTicks(magData_Inboard(:,3), magData_Inboard(:,5), magData_Inboard(:,1), magData_Inboard(:,2), 2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INZYP2');
    [ticks.INZZP2] = getTicks(magData_Inboard(:,3), magData_Inboard(:,6), magData_Inboard(:,1), magData_Inboard(:,2), 2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INZZP2');
  
    
    [ticks.INXXN2] = getTicks(magData_Inboard(:,1), magData_Inboard(:,4), magData_Inboard(:,2), magData_Inboard(:,3), -2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INXXN2');
    [ticks.INXYN2] = getTicks(magData_Inboard(:,1), magData_Inboard(:,5), magData_Inboard(:,2), magData_Inboard(:,3), -2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INXYN2');
    [ticks.INXZN2] = getTicks(magData_Inboard(:,1), magData_Inboard(:,6), magData_Inboard(:,2), magData_Inboard(:,3), -2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INXZN2');
    
    [ticks.INYXN2] = getTicks(magData_Inboard(:,2), magData_Inboard(:,4), magData_Inboard(:,1), magData_Inboard(:,3), -2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INYXN2');
    [ticks.INYYN2] = getTicks(magData_Inboard(:,2), magData_Inboard(:,5), magData_Inboard(:,1), magData_Inboard(:,3), -2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INYYN2');
    [ticks.INYZN2] = getTicks(magData_Inboard(:,2), magData_Inboard(:,6), magData_Inboard(:,1), magData_Inboard(:,3), -2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INYZN2');
    
    [ticks.INZXN2] = getTicks(magData_Inboard(:,3), magData_Inboard(:,4), magData_Inboard(:,1), magData_Inboard(:,2), -2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INZXN2');
    [ticks.INZYN2] = getTicks(magData_Inboard(:,3), magData_Inboard(:,5), magData_Inboard(:,1), magData_Inboard(:,2), -2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INZYN2');
    [ticks.INZZN2] = getTicks(magData_Inboard(:,3), magData_Inboard(:,6), magData_Inboard(:,1), magData_Inboard(:,2), -2, t_fit, hk_Inboard.Tsensor, hk_Inboard.Tebox, t_hk, 'INZZN2');

    [ticks.OUTXXP2] = getTicks(magData_Outboard(:,1), magData_Outboard(:,4), magData_Outboard(:,2), magData_Outboard(:,3), 2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTXXP2');
    [ticks.OUTXYP2] = getTicks(magData_Outboard(:,1), magData_Outboard(:,5), magData_Outboard(:,2), magData_Outboard(:,3), 2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTXYP2');
    [ticks.OUTXZP2] = getTicks(magData_Outboard(:,1), magData_Outboard(:,6), magData_Outboard(:,2), magData_Outboard(:,3), 2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTXZP2');
    
    [ticks.OUTYXP2] = getTicks(magData_Outboard(:,2), magData_Outboard(:,4), magData_Outboard(:,1), magData_Outboard(:,3), 2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTYXP2');
    [ticks.OUTYYP2] = getTicks(magData_Outboard(:,2), magData_Outboard(:,5), magData_Outboard(:,1), magData_Outboard(:,3), 2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTYYP2');
    [ticks.OUTYZP2] = getTicks(magData_Outboard(:,2), magData_Outboard(:,6), magData_Outboard(:,1), magData_Outboard(:,3), 2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTYZP2');
    
    [ticks.OUTZXP2] = getTicks(magData_Outboard(:,3), magData_Outboard(:,4), magData_Outboard(:,1), magData_Outboard(:,2), 2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTZXP2');
    [ticks.OUTZYP2] = getTicks(magData_Outboard(:,3), magData_Outboard(:,5), magData_Outboard(:,1), magData_Outboard(:,2), 2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTZYP2');
    [ticks.OUTZZP2] = getTicks(magData_Outboard(:,3), magData_Outboard(:,6), magData_Outboard(:,1), magData_Outboard(:,2), 2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTZZP2');
  
    
    [ticks.OUTXXN2] = getTicks(magData_Outboard(:,1), magData_Outboard(:,4), magData_Outboard(:,2), magData_Outboard(:,3), -2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTXXN2');
    [ticks.OUTXYN2] = getTicks(magData_Outboard(:,1), magData_Outboard(:,5), magData_Outboard(:,2), magData_Outboard(:,3), -2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTXYN2');
    [ticks.OUTXZN2] = getTicks(magData_Outboard(:,1), magData_Outboard(:,6), magData_Outboard(:,2), magData_Outboard(:,3), -2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTXZN2');
    
    [ticks.OUTYXN2] = getTicks(magData_Outboard(:,2), magData_Outboard(:,4), magData_Outboard(:,1), magData_Outboard(:,3), -2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTYXN2');
    [ticks.OUTYYN2] = getTicks(magData_Outboard(:,2), magData_Outboard(:,5), magData_Outboard(:,1), magData_Outboard(:,3), -2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTYYN2');
    [ticks.OUTYZN2] = getTicks(magData_Outboard(:,2), magData_Outboard(:,6), magData_Outboard(:,1), magData_Outboard(:,3), -2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTYZN2');
    
    [ticks.OUTZXN2] = getTicks(magData_Outboard(:,3), magData_Outboard(:,4), magData_Outboard(:,1), magData_Outboard(:,2), -2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTZXN2');
    [ticks.OUTZYN2] = getTicks(magData_Outboard(:,3), magData_Outboard(:,5), magData_Outboard(:,1), magData_Outboard(:,2), -2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTZYN2');
    [ticks.OUTZZN2] = getTicks(magData_Outboard(:,3), magData_Outboard(:,6), magData_Outboard(:,1), magData_Outboard(:,2), -2, t_fit, hk_Outboard.Tsensor, hk_Outboard.Tebox, t_hk, 'OUTZZN2');

    tickFileName = strcat(fileName,'.ticks');
    logStruct = mgfLog(logStruct, sprintf('Writing ticks to ''%s''', tickFileName), 'msg');
    
    save(tickFileName, 'ticks');
    
%     save(tickFileName, ... 
%         'INXXP2',  'INXYP2',  'INXZP2,  INYXP2,  INYYP2,  INYZP2,  INZXP2,  INZYP2,  INZZP2, ...
%         'OUTXXP2', 'OUTXYP2', 'OUTXZP2, OUTYXP2, OUTYYP2, OUTYZP2, OUTZXP2, OUTZYP2, OUTZZP2, ...
%         'INXXN2',  'INXYN2',  'INXZN2,  INYXN2,  INYYN2,  INYZN2,  INZXN2,  INZYN2,  INZZN2, ...
%         'OUTXXN2', 'OUTXYN2', 'OUTXZN2, OUTYXN2, OUTYYN2, OUTYZN2, OUTZXN2, OUTZYN2, OUTZZN2 );   
    
    hat = 1;
end


%% Save a copy of the DAC values for export
DAC_Inboard = magData_Inboard(:,1:3);
DAC_Outboard = magData_Outboard(:,1:3);


%% Detick data after DAC updates.

OutXadc = magData_Outboard(:,4);
OutYadc = magData_Outboard(:,5);
OutZadc = magData_Outboard(:,6);

InXadc = magData_Inboard(:,4);
InYadc = magData_Inboard(:,5);
InZadc = magData_Inboard(:,6);

if (p.Results.disableDetick)
    logStruct = mgfLog(logStruct,sprintf('Inboard - Deticking disabled FORCED by command line.\n'), 'warn');
elseif (p.Results.forceSimpleDetick) || ~( (version_Inboard(1) >= 1) && (version_Inboard(2) >= 3) && (version_Inboard(3) >= 0) )
    if (p.Results.forceSimpleDetick)
        logStruct = mgfLog(logStruct,sprintf('Inboard - Simple sample dropping detick FORCED by command line.\n'), 'warn');
    else
        logStruct = mgfLog(logStruct,sprintf('Inboard - Simple sample dropping detick running for < v1.3.0 firmware.\n'), 'warn');
    end
    
    tickCoeffs = loadV2TickCoeffs();
    
    coeffLen = numel(tickCoeffs.INXX.coeffs);
    
    
    % Stepping by +/- 2
    indInX = find( magData_Inboard(1:end-1,1) - magData_Inboard(2:end,1) == -2)+1;
    for i=1:numel(indInX)
        if indInX(i) < numel(InXadc) - coeffLen %% FIXME 
            InXadc(indInX(i):indInX(i)+coeffLen-1) = InXadc(indInX(i):indInX(i)+coeffLen-1) + transpose(tickCoeffs.INXX.coeffs);
            InYadc(indInX(i):indInX(i)+coeffLen-1) = InYadc(indInX(i):indInX(i)+coeffLen-1) + transpose(tickCoeffs.INXY.coeffs);
            InZadc(indInX(i):indInX(i)+coeffLen-1) = InZadc(indInX(i):indInX(i)+coeffLen-1) + transpose(tickCoeffs.INXZ.coeffs);
        end
    end

    indInX = find( magData_Inboard(1:end-1,1) - magData_Inboard(2:end,1) == 2)+1;
    for i=1:numel(indInX)
        if indInX(i) < numel(InXadc) - coeffLen
            InXadc(indInX(i):indInX(i)+coeffLen-1) = InXadc(indInX(i):indInX(i)+coeffLen-1) - transpose(tickCoeffs.INXX.coeffs);
            InYadc(indInX(i):indInX(i)+coeffLen-1) = InYadc(indInX(i):indInX(i)+coeffLen-1) - transpose(tickCoeffs.INXY.coeffs);
            InZadc(indInX(i):indInX(i)+coeffLen-1) = InZadc(indInX(i):indInX(i)+coeffLen-1) - transpose(tickCoeffs.INXZ.coeffs);
        end
    end


    indInY = find( magData_Inboard(1:end-1,2) - magData_Inboard(2:end,2) == -2)+1;
    for i=1:numel(indInY)
        if indInY(i) < numel(InXadc) - coeffLen
            InXadc(indInY(i):indInY(i)+coeffLen-1) = InXadc(indInY(i):indInY(i)+coeffLen-1) + transpose(tickCoeffs.INYX.coeffs);
            InYadc(indInY(i):indInY(i)+coeffLen-1) = InYadc(indInY(i):indInY(i)+coeffLen-1) + transpose(tickCoeffs.INYY.coeffs);
            InZadc(indInY(i):indInY(i)+coeffLen-1) = InZadc(indInY(i):indInY(i)+coeffLen-1) + transpose(tickCoeffs.INYZ.coeffs);
        end
    end

    indInY = find( magData_Inboard(1:end-1,2) - magData_Inboard(2:end,2) == 2)+1;
    for i=1:numel(indInY)
        if indInY(i) < numel(InXadc) - coeffLen
            InXadc(indInY(i):indInY(i)+coeffLen-1) = InXadc(indInY(i):indInY(i)+coeffLen-1) - transpose(tickCoeffs.INYX.coeffs);
            InYadc(indInY(i):indInY(i)+coeffLen-1) = InYadc(indInY(i):indInY(i)+coeffLen-1) - transpose(tickCoeffs.INYY.coeffs);
            InZadc(indInY(i):indInY(i)+coeffLen-1) = InZadc(indInY(i):indInY(i)+coeffLen-1) - transpose(tickCoeffs.INYZ.coeffs);
        end
    end


    indInZ = find( magData_Inboard(1:end-1,3) - magData_Inboard(2:end,3) == -2)+1;
    for i=1:numel(indInZ)
        if indInZ(i) < numel(InXadc) - coeffLen
            InXadc(indInZ(i):indInZ(i)+coeffLen-1) = InXadc(indInZ(i):indInZ(i)+coeffLen-1) + transpose(tickCoeffs.INZX.coeffs);
            InYadc(indInZ(i):indInZ(i)+coeffLen-1) = InYadc(indInZ(i):indInZ(i)+coeffLen-1) + transpose(tickCoeffs.INZY.coeffs);
            InZadc(indInZ(i):indInZ(i)+coeffLen-1) = InZadc(indInZ(i):indInZ(i)+coeffLen-1) + transpose(tickCoeffs.INZZ.coeffs);
        end
    end

    indInZ = find( magData_Inboard(1:end-1,3) - magData_Inboard(2:end,3) == 2)+1;
    for i=1:numel(indInZ)
        if indInZ(i) < numel(InXadc) - coeffLen
            InXadc(indInZ(i):indInZ(i)+coeffLen-1) = InXadc(indInZ(i):indInZ(i)+coeffLen-1) - transpose(tickCoeffs.INZX.coeffs);
            InYadc(indInZ(i):indInZ(i)+coeffLen-1) = InYadc(indInZ(i):indInZ(i)+coeffLen-1) - transpose(tickCoeffs.INZY.coeffs);
            InZadc(indInZ(i):indInZ(i)+coeffLen-1) = InZadc(indInZ(i):indInZ(i)+coeffLen-1) - transpose(tickCoeffs.INZZ.coeffs);
        end
    end
    
    
    % Stepping by +/- 3
    indInX = find( magData_Inboard(1:end-1,1) - magData_Inboard(2:end,1) == -3)+1;
    for i=1:numel(indInX)
        if indInX(i) < numel(InXadc) - coeffLen %% FIXME 
            InXadc(indInX(i):indInX(i)+coeffLen-1) = InXadc(indInX(i):indInX(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.INXX.coeffs);
            InYadc(indInX(i):indInX(i)+coeffLen-1) = InYadc(indInX(i):indInX(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.INXY.coeffs);
            InZadc(indInX(i):indInX(i)+coeffLen-1) = InZadc(indInX(i):indInX(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.INXZ.coeffs);
        end
    end

    indInX = find( magData_Inboard(1:end-1,1) - magData_Inboard(2:end,1) == 3)+1;
    for i=1:numel(indInX)
        if indInX(i) < numel(InXadc) - coeffLen
            InXadc(indInX(i):indInX(i)+coeffLen-1) = InXadc(indInX(i):indInX(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.INXX.coeffs);
            InYadc(indInX(i):indInX(i)+coeffLen-1) = InYadc(indInX(i):indInX(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.INXY.coeffs);
            InZadc(indInX(i):indInX(i)+coeffLen-1) = InZadc(indInX(i):indInX(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.INXZ.coeffs);
        end
    end


    indInY = find( magData_Inboard(1:end-1,2) - magData_Inboard(2:end,2) == -3)+1;
    for i=1:numel(indInY)
        if indInY(i) < numel(InXadc) - coeffLen
            InXadc(indInY(i):indInY(i)+coeffLen-1) = InXadc(indInY(i):indInY(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.INYX.coeffs);
            InYadc(indInY(i):indInY(i)+coeffLen-1) = InYadc(indInY(i):indInY(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.INYY.coeffs);
            InZadc(indInY(i):indInY(i)+coeffLen-1) = InZadc(indInY(i):indInY(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.INYZ.coeffs);
        end
    end

    indInY = find( magData_Inboard(1:end-1,2) - magData_Inboard(2:end,2) == 3)+1;
    for i=1:numel(indInY)
        if indInY(i) < numel(InXadc) - coeffLen
            InXadc(indInY(i):indInY(i)+coeffLen-1) = InXadc(indInY(i):indInY(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.INYX.coeffs);
            InYadc(indInY(i):indInY(i)+coeffLen-1) = InYadc(indInY(i):indInY(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.INYY.coeffs);
            InZadc(indInY(i):indInY(i)+coeffLen-1) = InZadc(indInY(i):indInY(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.INYZ.coeffs);
        end
    end


    indInZ = find( magData_Inboard(1:end-1,3) - magData_Inboard(2:end,3) == -3)+1;
    for i=1:numel(indInZ)
        if indInZ(i) < numel(InXadc) - coeffLen
            InXadc(indInZ(i):indInZ(i)+coeffLen-1) = InXadc(indInZ(i):indInZ(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.INZX.coeffs);
            InYadc(indInZ(i):indInZ(i)+coeffLen-1) = InYadc(indInZ(i):indInZ(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.INZY.coeffs);
            InZadc(indInZ(i):indInZ(i)+coeffLen-1) = InZadc(indInZ(i):indInZ(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.INZZ.coeffs);
        end
    end

    indInZ = find( magData_Inboard(1:end-1,3) - magData_Inboard(2:end,3) == 3)+1;
    for i=1:numel(indInZ)
        if indInZ(i) < numel(InXadc) - coeffLen
            InXadc(indInZ(i):indInZ(i)+coeffLen-1) = InXadc(indInZ(i):indInZ(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.INZX.coeffs);
            InYadc(indInZ(i):indInZ(i)+coeffLen-1) = InYadc(indInZ(i):indInZ(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.INZY.coeffs);
            InZadc(indInZ(i):indInZ(i)+coeffLen-1) = InZadc(indInZ(i):indInZ(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.INZZ.coeffs);
        end
    end
    
    % Stepping by +/- 4
    indInX = find( magData_Inboard(1:end-1,1) - magData_Inboard(2:end,1) == -4)+1;
    for i=1:numel(indInX)
        if indInX(i) < numel(InXadc) - coeffLen %% FIXME 
            InXadc(indInX(i):indInX(i)+coeffLen-1) = InXadc(indInX(i):indInX(i)+coeffLen-1) + 2*transpose(tickCoeffs.INXX.coeffs);
            InYadc(indInX(i):indInX(i)+coeffLen-1) = InYadc(indInX(i):indInX(i)+coeffLen-1) + 2*transpose(tickCoeffs.INXY.coeffs);
            InZadc(indInX(i):indInX(i)+coeffLen-1) = InZadc(indInX(i):indInX(i)+coeffLen-1) + 2*transpose(tickCoeffs.INXZ.coeffs);
        end
    end

    indInX = find( magData_Inboard(1:end-1,1) - magData_Inboard(2:end,1) == 4)+1;
    for i=1:numel(indInX)
        if indInX(i) < numel(InXadc) - coeffLen
            InXadc(indInX(i):indInX(i)+coeffLen-1) = InXadc(indInX(i):indInX(i)+coeffLen-1) - 2*transpose(tickCoeffs.INXX.coeffs);
            InYadc(indInX(i):indInX(i)+coeffLen-1) = InYadc(indInX(i):indInX(i)+coeffLen-1) - 2*transpose(tickCoeffs.INXY.coeffs);
            InZadc(indInX(i):indInX(i)+coeffLen-1) = InZadc(indInX(i):indInX(i)+coeffLen-1) - 2*transpose(tickCoeffs.INXZ.coeffs);
        end
    end


    indInY = find( magData_Inboard(1:end-1,2) - magData_Inboard(2:end,2) == -4)+1;
    for i=1:numel(indInY)
        if indInY(i) < numel(InXadc) - coeffLen
            InXadc(indInY(i):indInY(i)+coeffLen-1) = InXadc(indInY(i):indInY(i)+coeffLen-1) + 2*transpose(tickCoeffs.INYX.coeffs);
            InYadc(indInY(i):indInY(i)+coeffLen-1) = InYadc(indInY(i):indInY(i)+coeffLen-1) + 2*transpose(tickCoeffs.INYY.coeffs);
            InZadc(indInY(i):indInY(i)+coeffLen-1) = InZadc(indInY(i):indInY(i)+coeffLen-1) + 2*transpose(tickCoeffs.INYZ.coeffs);
        end
    end

    indInY = find( magData_Inboard(1:end-1,2) - magData_Inboard(2:end,2) == 4)+1;
    for i=1:numel(indInY)
        if indInY(i) < numel(InXadc) - coeffLen
            InXadc(indInY(i):indInY(i)+coeffLen-1) = InXadc(indInY(i):indInY(i)+coeffLen-1) - 2*transpose(tickCoeffs.INYX.coeffs);
            InYadc(indInY(i):indInY(i)+coeffLen-1) = InYadc(indInY(i):indInY(i)+coeffLen-1) - 2*transpose(tickCoeffs.INYY.coeffs);
            InZadc(indInY(i):indInY(i)+coeffLen-1) = InZadc(indInY(i):indInY(i)+coeffLen-1) - 2*transpose(tickCoeffs.INYZ.coeffs);
        end
    end


    indInZ = find( magData_Inboard(1:end-1,3) - magData_Inboard(2:end,3) == -4)+1;
    for i=1:numel(indInZ)
        if indInZ(i) < numel(InXadc) - coeffLen
            InXadc(indInZ(i):indInZ(i)+coeffLen-1) = InXadc(indInZ(i):indInZ(i)+coeffLen-1) + 2*transpose(tickCoeffs.INZX.coeffs);
            InYadc(indInZ(i):indInZ(i)+coeffLen-1) = InYadc(indInZ(i):indInZ(i)+coeffLen-1) + 2*transpose(tickCoeffs.INZY.coeffs);
            InZadc(indInZ(i):indInZ(i)+coeffLen-1) = InZadc(indInZ(i):indInZ(i)+coeffLen-1) + 2*transpose(tickCoeffs.INZZ.coeffs);
        end
    end

    indInZ = find( magData_Inboard(1:end-1,3) - magData_Inboard(2:end,3) == 4)+1;
    for i=1:numel(indInZ)
        if indInZ(i) < numel(InXadc) - coeffLen
            InXadc(indInZ(i):indInZ(i)+coeffLen-1) = InXadc(indInZ(i):indInZ(i)+coeffLen-1) - 2*transpose(tickCoeffs.INZX.coeffs);
            InYadc(indInZ(i):indInZ(i)+coeffLen-1) = InYadc(indInZ(i):indInZ(i)+coeffLen-1) - 2*transpose(tickCoeffs.INZY.coeffs);
            InZadc(indInZ(i):indInZ(i)+coeffLen-1) = InZadc(indInZ(i):indInZ(i)+coeffLen-1) - 2*transpose(tickCoeffs.INZZ.coeffs);
        end
    end
else
    logStruct = mgfLog(logStruct,sprintf('Inboard - Experimental fitted detick running.\n'), 'warn');
    
    load('tickCoeffs.mat');
    coeffLen = numel(tickCoeffs(9).INXX.coeffs);
    
    % Stepping by +/- 2
    indInX = find( magData_Inboard(1:end-1,1) - magData_Inboard(2:end,1) == -2)+1;
    for i=1:numel(indInX)
        if indInX(i) < numel(InXadc) - coeffLen %% FIXME 
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInX(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInX(i):indInX(i)+coeffLen-1) = InXadc(indInX(i):indInX(i)+coeffLen-1) + transpose(tickCoeffAtTemp.INXX.coeffs);
            InYadc(indInX(i):indInX(i)+coeffLen-1) = InYadc(indInX(i):indInX(i)+coeffLen-1) + transpose(tickCoeffAtTemp.INXY.coeffs);
            InZadc(indInX(i):indInX(i)+coeffLen-1) = InZadc(indInX(i):indInX(i)+coeffLen-1) + transpose(tickCoeffAtTemp.INXZ.coeffs);
        end
    end

    indInX = find( magData_Inboard(1:end-1,1) - magData_Inboard(2:end,1) == 2)+1;
    for i=1:numel(indInX)
        if indInX(i) < numel(InXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInX(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInX(i):indInX(i)+coeffLen-1) = InXadc(indInX(i):indInX(i)+coeffLen-1) - transpose(tickCoeffAtTemp.INXX.coeffs);
            InYadc(indInX(i):indInX(i)+coeffLen-1) = InYadc(indInX(i):indInX(i)+coeffLen-1) - transpose(tickCoeffAtTemp.INXY.coeffs);
            InZadc(indInX(i):indInX(i)+coeffLen-1) = InZadc(indInX(i):indInX(i)+coeffLen-1) - transpose(tickCoeffAtTemp.INXZ.coeffs);
        end
    end


    indInY = find( magData_Inboard(1:end-1,2) - magData_Inboard(2:end,2) == -2)+1;
    for i=1:numel(indInY)
        if indInY(i) < numel(InXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInY(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInY(i):indInY(i)+coeffLen-1) = InXadc(indInY(i):indInY(i)+coeffLen-1) + transpose(tickCoeffAtTemp.INYX.coeffs);
            InYadc(indInY(i):indInY(i)+coeffLen-1) = InYadc(indInY(i):indInY(i)+coeffLen-1) + transpose(tickCoeffAtTemp.INYY.coeffs);
            InZadc(indInY(i):indInY(i)+coeffLen-1) = InZadc(indInY(i):indInY(i)+coeffLen-1) + transpose(tickCoeffAtTemp.INYZ.coeffs);
        end
    end

    indInY = find( magData_Inboard(1:end-1,2) - magData_Inboard(2:end,2) == 2)+1;
    for i=1:numel(indInY)
        if indInY(i) < numel(InXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInY(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInY(i):indInY(i)+coeffLen-1) = InXadc(indInY(i):indInY(i)+coeffLen-1) - transpose(tickCoeffAtTemp.INYX.coeffs);
            InYadc(indInY(i):indInY(i)+coeffLen-1) = InYadc(indInY(i):indInY(i)+coeffLen-1) - transpose(tickCoeffAtTemp.INYY.coeffs);
            InZadc(indInY(i):indInY(i)+coeffLen-1) = InZadc(indInY(i):indInY(i)+coeffLen-1) - transpose(tickCoeffAtTemp.INYZ.coeffs);
        end
    end


    indInZ = find( magData_Inboard(1:end-1,3) - magData_Inboard(2:end,3) == -2)+1;
    for i=1:numel(indInZ)
        if indInZ(i) < numel(InXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInZ(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInZ(i):indInZ(i)+coeffLen-1) = InXadc(indInZ(i):indInZ(i)+coeffLen-1) + transpose(tickCoeffAtTemp.INZX.coeffs);
            InYadc(indInZ(i):indInZ(i)+coeffLen-1) = InYadc(indInZ(i):indInZ(i)+coeffLen-1) + transpose(tickCoeffAtTemp.INZY.coeffs);
            InZadc(indInZ(i):indInZ(i)+coeffLen-1) = InZadc(indInZ(i):indInZ(i)+coeffLen-1) + transpose(tickCoeffAtTemp.INZZ.coeffs);
        end
    end

    indInZ = find( magData_Inboard(1:end-1,3) - magData_Inboard(2:end,3) == 2)+1;
    for i=1:numel(indInZ)
        if indInZ(i) < numel(InXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInZ(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInZ(i):indInZ(i)+coeffLen-1) = InXadc(indInZ(i):indInZ(i)+coeffLen-1) - transpose(tickCoeffAtTemp.INZX.coeffs);
            InYadc(indInZ(i):indInZ(i)+coeffLen-1) = InYadc(indInZ(i):indInZ(i)+coeffLen-1) - transpose(tickCoeffAtTemp.INZY.coeffs);
            InZadc(indInZ(i):indInZ(i)+coeffLen-1) = InZadc(indInZ(i):indInZ(i)+coeffLen-1) - transpose(tickCoeffAtTemp.INZZ.coeffs);
        end
    end
    
    
    % Stepping by +/- 3
    indInX = find( magData_Inboard(1:end-1,1) - magData_Inboard(2:end,1) == -3)+1;
    for i=1:numel(indInX)
        if indInX(i) < numel(InXadc) - coeffLen %% FIXME 
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInX(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInX(i):indInX(i)+coeffLen-1) = InXadc(indInX(i):indInX(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.INXX.coeffs);
            InYadc(indInX(i):indInX(i)+coeffLen-1) = InYadc(indInX(i):indInX(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.INXY.coeffs);
            InZadc(indInX(i):indInX(i)+coeffLen-1) = InZadc(indInX(i):indInX(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.INXZ.coeffs);
        end
    end

    indInX = find( magData_Inboard(1:end-1,1) - magData_Inboard(2:end,1) == 3)+1;
    for i=1:numel(indInX)
        if indInX(i) < numel(InXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInX(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInX(i):indInX(i)+coeffLen-1) = InXadc(indInX(i):indInX(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.INXX.coeffs);
            InYadc(indInX(i):indInX(i)+coeffLen-1) = InYadc(indInX(i):indInX(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.INXY.coeffs);
            InZadc(indInX(i):indInX(i)+coeffLen-1) = InZadc(indInX(i):indInX(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.INXZ.coeffs);
        end
    end


    indInY = find( magData_Inboard(1:end-1,2) - magData_Inboard(2:end,2) == -3)+1;
    for i=1:numel(indInY)
        if indInY(i) < numel(InXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInY(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInY(i):indInY(i)+coeffLen-1) = InXadc(indInY(i):indInY(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.INYX.coeffs);
            InYadc(indInY(i):indInY(i)+coeffLen-1) = InYadc(indInY(i):indInY(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.INYY.coeffs);
            InZadc(indInY(i):indInY(i)+coeffLen-1) = InZadc(indInY(i):indInY(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.INYZ.coeffs);
        end
    end

    indInY = find( magData_Inboard(1:end-1,2) - magData_Inboard(2:end,2) == 3)+1;
    for i=1:numel(indInY)
        if indInY(i) < numel(InXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInY(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInY(i):indInY(i)+coeffLen-1) = InXadc(indInY(i):indInY(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.INYX.coeffs);
            InYadc(indInY(i):indInY(i)+coeffLen-1) = InYadc(indInY(i):indInY(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.INYY.coeffs);
            InZadc(indInY(i):indInY(i)+coeffLen-1) = InZadc(indInY(i):indInY(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.INYZ.coeffs);
        end
    end


    indInZ = find( magData_Inboard(1:end-1,3) - magData_Inboard(2:end,3) == -3)+1;
    for i=1:numel(indInZ)
        if indInZ(i) < numel(InXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInZ(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInZ(i):indInZ(i)+coeffLen-1) = InXadc(indInZ(i):indInZ(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.INZX.coeffs);
            InYadc(indInZ(i):indInZ(i)+coeffLen-1) = InYadc(indInZ(i):indInZ(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.INZY.coeffs);
            InZadc(indInZ(i):indInZ(i)+coeffLen-1) = InZadc(indInZ(i):indInZ(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.INZZ.coeffs);
        end
    end

    indInZ = find( magData_Inboard(1:end-1,3) - magData_Inboard(2:end,3) == 3)+1;
    for i=1:numel(indInZ)
        if indInZ(i) < numel(InXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInZ(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInZ(i):indInZ(i)+coeffLen-1) = InXadc(indInZ(i):indInZ(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.INZX.coeffs);
            InYadc(indInZ(i):indInZ(i)+coeffLen-1) = InYadc(indInZ(i):indInZ(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.INZY.coeffs);
            InZadc(indInZ(i):indInZ(i)+coeffLen-1) = InZadc(indInZ(i):indInZ(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.INZZ.coeffs);
        end
    end
    
    
    % Stepping by +/- 4
    indInX = find( magData_Inboard(1:end-1,1) - magData_Inboard(2:end,1) == -4)+1;
    for i=1:numel(indInX)
        if indInX(i) < numel(InXadc) - coeffLen %% FIXME 
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInX(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInX(i):indInX(i)+coeffLen-1) = InXadc(indInX(i):indInX(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.INXX.coeffs);
            InYadc(indInX(i):indInX(i)+coeffLen-1) = InYadc(indInX(i):indInX(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.INXY.coeffs);
            InZadc(indInX(i):indInX(i)+coeffLen-1) = InZadc(indInX(i):indInX(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.INXZ.coeffs);
        end
    end

    indInX = find( magData_Inboard(1:end-1,1) - magData_Inboard(2:end,1) == 4)+1;
    for i=1:numel(indInX)
        if indInX(i) < numel(InXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInX(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInX(i):indInX(i)+coeffLen-1) = InXadc(indInX(i):indInX(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.INXX.coeffs);
            InYadc(indInX(i):indInX(i)+coeffLen-1) = InYadc(indInX(i):indInX(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.INXY.coeffs);
            InZadc(indInX(i):indInX(i)+coeffLen-1) = InZadc(indInX(i):indInX(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.INXZ.coeffs);
        end
    end


    indInY = find( magData_Inboard(1:end-1,2) - magData_Inboard(2:end,2) == -4)+1;
    for i=1:numel(indInY)
        if indInY(i) < numel(InXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInY(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInY(i):indInY(i)+coeffLen-1) = InXadc(indInY(i):indInY(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.INYX.coeffs);
            InYadc(indInY(i):indInY(i)+coeffLen-1) = InYadc(indInY(i):indInY(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.INYY.coeffs);
            InZadc(indInY(i):indInY(i)+coeffLen-1) = InZadc(indInY(i):indInY(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.INYZ.coeffs);
        end
    end

    indInY = find( magData_Inboard(1:end-1,2) - magData_Inboard(2:end,2) == 4)+1;
    for i=1:numel(indInY)
        if indInY(i) < numel(InXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInY(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInY(i):indInY(i)+coeffLen-1) = InXadc(indInY(i):indInY(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.INYX.coeffs);
            InYadc(indInY(i):indInY(i)+coeffLen-1) = InYadc(indInY(i):indInY(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.INYY.coeffs);
            InZadc(indInY(i):indInY(i)+coeffLen-1) = InZadc(indInY(i):indInY(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.INYZ.coeffs);
        end
    end


    indInZ = find( magData_Inboard(1:end-1,3) - magData_Inboard(2:end,3) == -4)+1;
    for i=1:numel(indInZ)
        if indInZ(i) < numel(InXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInZ(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInZ(i):indInZ(i)+coeffLen-1) = InXadc(indInZ(i):indInZ(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.INZX.coeffs);
            InYadc(indInZ(i):indInZ(i)+coeffLen-1) = InYadc(indInZ(i):indInZ(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.INZY.coeffs);
            InZadc(indInZ(i):indInZ(i)+coeffLen-1) = InZadc(indInZ(i):indInZ(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.INZZ.coeffs);
        end
    end

    indInZ = find( magData_Inboard(1:end-1,3) - magData_Inboard(2:end,3) == 4)+1;
    for i=1:numel(indInZ)
        if indInZ(i) < numel(InXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indInZ(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            InXadc(indInZ(i):indInZ(i)+coeffLen-1) = InXadc(indInZ(i):indInZ(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.INZX.coeffs);
            InYadc(indInZ(i):indInZ(i)+coeffLen-1) = InYadc(indInZ(i):indInZ(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.INZY.coeffs);
            InZadc(indInZ(i):indInZ(i)+coeffLen-1) = InZadc(indInZ(i):indInZ(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.INZZ.coeffs);
        end
    end
    
end

if (p.Results.disableDetick)
    logStruct = mgfLog(logStruct,sprintf('Outboard - Deticking disabled FORCED by command line.\n'), 'warn');
elseif (p.Results.forceSimpleDetick) || ~( (version_Outboard(1) >= 1) && (version_Outboard(2) >= 3) && (version_Outboard(3) >= 0) )
    if (p.Results.forceSimpleDetick)
        logStruct = mgfLog(logStruct,sprintf('Outboard - Simple sample dropping detick FORCED by command line.\n'), 'warn');
    else
        logStruct = mgfLog(logStruct,sprintf('Outboard - Simple sample dropping detick running for < v1.3.0 firmware.\n'), 'warn');
    end
    
    tickCoeffs = loadV2TickCoeffs();
    coeffLen = numel(tickCoeffs.INXX.coeffs);
    
    % Stepping by +/- 2
    indOutX = find( magData_Outboard(1:end-1,1) - magData_Outboard(2:end,1) == -2)+1;
    for i=1:numel(indOutX)
        if indOutX(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutX(i):indOutX(i)+coeffLen-1) = OutXadc(indOutX(i):indOutX(i)+coeffLen-1) + transpose(tickCoeffs.OUTXX.coeffs);
            OutYadc(indOutX(i):indOutX(i)+coeffLen-1) = OutYadc(indOutX(i):indOutX(i)+coeffLen-1) + transpose(tickCoeffs.OUTXY.coeffs);
            OutZadc(indOutX(i):indOutX(i)+coeffLen-1) = OutZadc(indOutX(i):indOutX(i)+coeffLen-1) + transpose(tickCoeffs.OUTXZ.coeffs);
        end
    end

    indOutX = find( magData_Outboard(1:end-1,1) - magData_Outboard(2:end,1) == 2)+1;
    for i=1:numel(indOutX)
        if indOutX(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutX(i):indOutX(i)+coeffLen-1) = OutXadc(indOutX(i):indOutX(i)+coeffLen-1) - transpose(tickCoeffs.OUTXX.coeffs);
            OutYadc(indOutX(i):indOutX(i)+coeffLen-1) = OutYadc(indOutX(i):indOutX(i)+coeffLen-1) - transpose(tickCoeffs.OUTXY.coeffs);
            OutZadc(indOutX(i):indOutX(i)+coeffLen-1) = OutZadc(indOutX(i):indOutX(i)+coeffLen-1) - transpose(tickCoeffs.OUTXZ.coeffs);
        end
    end


    indOutY = find( magData_Outboard(1:end-1,2) - magData_Outboard(2:end,2) == -2)+1;
    for i=1:numel(indOutY)
        if indOutY(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutY(i):indOutY(i)+coeffLen-1) = OutXadc(indOutY(i):indOutY(i)+coeffLen-1) + transpose(tickCoeffs.OUTYX.coeffs);
            OutYadc(indOutY(i):indOutY(i)+coeffLen-1) = OutYadc(indOutY(i):indOutY(i)+coeffLen-1) + transpose(tickCoeffs.OUTYY.coeffs);
            OutZadc(indOutY(i):indOutY(i)+coeffLen-1) = OutZadc(indOutY(i):indOutY(i)+coeffLen-1) + transpose(tickCoeffs.OUTYZ.coeffs);
        end
    end

    indOutY = find( magData_Outboard(1:end-1,2) - magData_Outboard(2:end,2) == 2)+1;
    for i=1:numel(indOutY)
        if indOutY(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutY(i):indOutY(i)+coeffLen-1) = OutXadc(indOutY(i):indOutY(i)+coeffLen-1) - transpose(tickCoeffs.OUTYX.coeffs);
            OutYadc(indOutY(i):indOutY(i)+coeffLen-1) = OutYadc(indOutY(i):indOutY(i)+coeffLen-1) - transpose(tickCoeffs.OUTYY.coeffs);
            OutZadc(indOutY(i):indOutY(i)+coeffLen-1) = OutZadc(indOutY(i):indOutY(i)+coeffLen-1) - transpose(tickCoeffs.OUTYZ.coeffs);
        end
    end


    indOutZ = find( magData_Outboard(1:end-1,3) - magData_Outboard(2:end,3) == -2)+1;
    for i=1:numel(indOutZ)
        if indOutZ(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) + transpose(tickCoeffs.OUTZX.coeffs);
            OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) + transpose(tickCoeffs.OUTZY.coeffs);
            OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) + transpose(tickCoeffs.OUTZZ.coeffs);
        end
    end

    indOutZ = find( magData_Outboard(1:end-1,3) - magData_Outboard(2:end,3) == 2)+1;
    for i=1:numel(indOutZ)
        if indOutZ(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) - transpose(tickCoeffs.OUTZX.coeffs);
            OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) - transpose(tickCoeffs.OUTZY.coeffs);
            OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) - transpose(tickCoeffs.OUTZZ.coeffs);
        end
    end    
    
    
    % Stepping by +/- 3
    indOutX = find( magData_Outboard(1:end-1,1) - magData_Outboard(2:end,1) == -3)+1;
    for i=1:numel(indOutX)
        if indOutX(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutX(i):indOutX(i)+coeffLen-1) = OutXadc(indOutX(i):indOutX(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.OUTXX.coeffs);
            OutYadc(indOutX(i):indOutX(i)+coeffLen-1) = OutYadc(indOutX(i):indOutX(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.OUTXY.coeffs);
            OutZadc(indOutX(i):indOutX(i)+coeffLen-1) = OutZadc(indOutX(i):indOutX(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.OUTXZ.coeffs);
        end
    end

    indOutX = find( magData_Outboard(1:end-1,1) - magData_Outboard(2:end,1) == 3)+1;
    for i=1:numel(indOutX)
        if indOutX(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutX(i):indOutX(i)+coeffLen-1) = OutXadc(indOutX(i):indOutX(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.OUTXX.coeffs);
            OutYadc(indOutX(i):indOutX(i)+coeffLen-1) = OutYadc(indOutX(i):indOutX(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.OUTXY.coeffs);
            OutZadc(indOutX(i):indOutX(i)+coeffLen-1) = OutZadc(indOutX(i):indOutX(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.OUTXZ.coeffs);
        end
    end


    indOutY = find( magData_Outboard(1:end-1,2) - magData_Outboard(2:end,2) == -3)+1;
    for i=1:numel(indOutY)
        if indOutY(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutY(i):indOutY(i)+coeffLen-1) = OutXadc(indOutY(i):indOutY(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.OUTYX.coeffs);
            OutYadc(indOutY(i):indOutY(i)+coeffLen-1) = OutYadc(indOutY(i):indOutY(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.OUTYY.coeffs);
            OutZadc(indOutY(i):indOutY(i)+coeffLen-1) = OutZadc(indOutY(i):indOutY(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.OUTYZ.coeffs);
        end
    end

    indOutY = find( magData_Outboard(1:end-1,2) - magData_Outboard(2:end,2) == 3)+1;
    for i=1:numel(indOutY)
        if indOutY(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutY(i):indOutY(i)+coeffLen-1) = OutXadc(indOutY(i):indOutY(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.OUTYX.coeffs);
            OutYadc(indOutY(i):indOutY(i)+coeffLen-1) = OutYadc(indOutY(i):indOutY(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.OUTYY.coeffs);
            OutZadc(indOutY(i):indOutY(i)+coeffLen-1) = OutZadc(indOutY(i):indOutY(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.OUTYZ.coeffs);
        end
    end


    indOutZ = find( magData_Outboard(1:end-1,3) - magData_Outboard(2:end,3) == -3)+1;
    for i=1:numel(indOutZ)
        if indOutZ(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.OUTZX.coeffs);
            OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.OUTZY.coeffs);
            OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) + 1.5*transpose(tickCoeffs.OUTZZ.coeffs);
        end
    end

    indOutZ = find( magData_Outboard(1:end-1,3) - magData_Outboard(2:end,3) == 3)+1;
    for i=1:numel(indOutZ)
        if indOutZ(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.OUTZX.coeffs);
            OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.OUTZY.coeffs);
            OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) - 1.5*transpose(tickCoeffs.OUTZZ.coeffs);
        end
    end
    
    
    % Stepping by +/- 4
    indOutX = find( magData_Outboard(1:end-1,1) - magData_Outboard(2:end,1) == -4)+1;
    for i=1:numel(indOutX)
        if indOutX(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutX(i):indOutX(i)+coeffLen-1) = OutXadc(indOutX(i):indOutX(i)+coeffLen-1) + 2*transpose(tickCoeffs.OUTXX.coeffs);
            OutYadc(indOutX(i):indOutX(i)+coeffLen-1) = OutYadc(indOutX(i):indOutX(i)+coeffLen-1) + 2*transpose(tickCoeffs.OUTXY.coeffs);
            OutZadc(indOutX(i):indOutX(i)+coeffLen-1) = OutZadc(indOutX(i):indOutX(i)+coeffLen-1) + 2*transpose(tickCoeffs.OUTXZ.coeffs);
        end
    end

    indOutX = find( magData_Outboard(1:end-1,1) - magData_Outboard(2:end,1) == 4)+1;
    for i=1:numel(indOutX)
        if indOutX(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutX(i):indOutX(i)+coeffLen-1) = OutXadc(indOutX(i):indOutX(i)+coeffLen-1) - 2*transpose(tickCoeffs.OUTXX.coeffs);
            OutYadc(indOutX(i):indOutX(i)+coeffLen-1) = OutYadc(indOutX(i):indOutX(i)+coeffLen-1) - 2*transpose(tickCoeffs.OUTXY.coeffs);
            OutZadc(indOutX(i):indOutX(i)+coeffLen-1) = OutZadc(indOutX(i):indOutX(i)+coeffLen-1) - 2*transpose(tickCoeffs.OUTXZ.coeffs);
        end
    end


    indOutY = find( magData_Outboard(1:end-1,2) - magData_Outboard(2:end,2) == -4)+1;
    for i=1:numel(indOutY)
        if indOutY(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutY(i):indOutY(i)+coeffLen-1) = OutXadc(indOutY(i):indOutY(i)+coeffLen-1) + 2*transpose(tickCoeffs.OUTYX.coeffs);
            OutYadc(indOutY(i):indOutY(i)+coeffLen-1) = OutYadc(indOutY(i):indOutY(i)+coeffLen-1) + 2*transpose(tickCoeffs.OUTYY.coeffs);
            OutZadc(indOutY(i):indOutY(i)+coeffLen-1) = OutZadc(indOutY(i):indOutY(i)+coeffLen-1) + 2*transpose(tickCoeffs.OUTYZ.coeffs);
        end
    end

    indOutY = find( magData_Outboard(1:end-1,2) - magData_Outboard(2:end,2) == 4)+1;
    for i=1:numel(indOutY)
        if indOutY(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutY(i):indOutY(i)+coeffLen-1) = OutXadc(indOutY(i):indOutY(i)+coeffLen-1) - 2*transpose(tickCoeffs.OUTYX.coeffs);
            OutYadc(indOutY(i):indOutY(i)+coeffLen-1) = OutYadc(indOutY(i):indOutY(i)+coeffLen-1) - 2*transpose(tickCoeffs.OUTYY.coeffs);
            OutZadc(indOutY(i):indOutY(i)+coeffLen-1) = OutZadc(indOutY(i):indOutY(i)+coeffLen-1) - 2*transpose(tickCoeffs.OUTYZ.coeffs);
        end
    end


    indOutZ = find( magData_Outboard(1:end-1,3) - magData_Outboard(2:end,3) == -4)+1;
    for i=1:numel(indOutZ)
        if indOutZ(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) + 2*transpose(tickCoeffs.OUTZX.coeffs);
            OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) + 2*transpose(tickCoeffs.OUTZY.coeffs);
            OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) + 2*transpose(tickCoeffs.OUTZZ.coeffs);
        end
    end

    indOutZ = find( magData_Outboard(1:end-1,3) - magData_Outboard(2:end,3) == 4)+1;
    for i=1:numel(indOutZ)
        if indOutZ(i) < numel(OutXadc) - coeffLen
            OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) - 2*transpose(tickCoeffs.OUTZX.coeffs);
            OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) - 2*transpose(tickCoeffs.OUTZY.coeffs);
            OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) - 2*transpose(tickCoeffs.OUTZZ.coeffs);
        end
    end
    
else
    logStruct = mgfLog(logStruct,sprintf('Outboard - Experimental fitted detick running.\n'), 'warn');
    load('tickCoeffs.mat');
    
    % Stepping by +/- 2
    indOutX = find( magData_Outboard(1:end-1,1) - magData_Outboard(2:end,1) == -2)+1;
    for i=1:numel(indOutX)
        if indOutX(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutX(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutX(i):indOutX(i)+coeffLen-1) = OutXadc(indOutX(i):indOutX(i)+coeffLen-1) + transpose(tickCoeffAtTemp.OUTXX.coeffs);
            OutYadc(indOutX(i):indOutX(i)+coeffLen-1) = OutYadc(indOutX(i):indOutX(i)+coeffLen-1) + transpose(tickCoeffAtTemp.OUTXY.coeffs);
            OutZadc(indOutX(i):indOutX(i)+coeffLen-1) = OutZadc(indOutX(i):indOutX(i)+coeffLen-1) + transpose(tickCoeffAtTemp.OUTXZ.coeffs);
        end
    end

    indOutX = find( magData_Outboard(1:end-1,1) - magData_Outboard(2:end,1) == 2)+1;
    for i=1:numel(indOutX)
        if indOutX(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutX(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutX(i):indOutX(i)+coeffLen-1) = OutXadc(indOutX(i):indOutX(i)+coeffLen-1) - transpose(tickCoeffAtTemp.OUTXX.coeffs);
            OutYadc(indOutX(i):indOutX(i)+coeffLen-1) = OutYadc(indOutX(i):indOutX(i)+coeffLen-1) - transpose(tickCoeffAtTemp.OUTXY.coeffs);
            OutZadc(indOutX(i):indOutX(i)+coeffLen-1) = OutZadc(indOutX(i):indOutX(i)+coeffLen-1) - transpose(tickCoeffAtTemp.OUTXZ.coeffs);
        end
    end


    indOutY = find( magData_Outboard(1:end-1,2) - magData_Outboard(2:end,2) == -2)+1;
    for i=1:numel(indOutY)
        if indOutY(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutY(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutY(i):indOutY(i)+coeffLen-1) = OutXadc(indOutY(i):indOutY(i)+coeffLen-1) + transpose(tickCoeffAtTemp.OUTYX.coeffs);
            OutYadc(indOutY(i):indOutY(i)+coeffLen-1) = OutYadc(indOutY(i):indOutY(i)+coeffLen-1) + transpose(tickCoeffAtTemp.OUTYY.coeffs);
            OutZadc(indOutY(i):indOutY(i)+coeffLen-1) = OutZadc(indOutY(i):indOutY(i)+coeffLen-1) + transpose(tickCoeffAtTemp.OUTYZ.coeffs);
        end
    end

    indOutY = find( magData_Outboard(1:end-1,2) - magData_Outboard(2:end,2) == 2)+1;
    for i=1:numel(indOutY)
        if indOutY(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutY(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutY(i):indOutY(i)+coeffLen-1) = OutXadc(indOutY(i):indOutY(i)+coeffLen-1) - transpose(tickCoeffAtTemp.OUTYX.coeffs);
            OutYadc(indOutY(i):indOutY(i)+coeffLen-1) = OutYadc(indOutY(i):indOutY(i)+coeffLen-1) - transpose(tickCoeffAtTemp.OUTYY.coeffs);
            OutZadc(indOutY(i):indOutY(i)+coeffLen-1) = OutZadc(indOutY(i):indOutY(i)+coeffLen-1) - transpose(tickCoeffAtTemp.OUTYZ.coeffs);
        end
    end


    indOutZ = find( magData_Outboard(1:end-1,3) - magData_Outboard(2:end,3) == -2)+1;
    for i=1:numel(indOutZ)
        if indOutZ(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutZ(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) + transpose(tickCoeffAtTemp.OUTZX.coeffs);
            OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) + transpose(tickCoeffAtTemp.OUTZY.coeffs);
            OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) + transpose(tickCoeffAtTemp.OUTZZ.coeffs);
        end
    end

    indOutZ = find( magData_Outboard(1:end-1,3) - magData_Outboard(2:end,3) == 2)+1;
    for i=1:numel(indOutZ)
        if indOutZ(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutZ(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) - transpose(tickCoeffAtTemp.OUTZX.coeffs);
            OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) - transpose(tickCoeffAtTemp.OUTZY.coeffs);
            OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) - transpose(tickCoeffAtTemp.OUTZZ.coeffs);
        end
    end
    
    
    % Stepping by +/- 3
    indOutX = find( magData_Outboard(1:end-1,1) - magData_Outboard(2:end,1) == -3)+1;
    for i=1:numel(indOutX)
        if indOutX(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutX(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutX(i):indOutX(i)+coeffLen-1) = OutXadc(indOutX(i):indOutX(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.OUTXX.coeffs);
            OutYadc(indOutX(i):indOutX(i)+coeffLen-1) = OutYadc(indOutX(i):indOutX(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.OUTXY.coeffs);
            OutZadc(indOutX(i):indOutX(i)+coeffLen-1) = OutZadc(indOutX(i):indOutX(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.OUTXZ.coeffs);
        end
    end

    indOutX = find( magData_Outboard(1:end-1,1) - magData_Outboard(2:end,1) == 3)+1;
    for i=1:numel(indOutX)
        if indOutX(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutX(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutX(i):indOutX(i)+coeffLen-1) = OutXadc(indOutX(i):indOutX(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.OUTXX.coeffs);
            OutYadc(indOutX(i):indOutX(i)+coeffLen-1) = OutYadc(indOutX(i):indOutX(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.OUTXY.coeffs);
            OutZadc(indOutX(i):indOutX(i)+coeffLen-1) = OutZadc(indOutX(i):indOutX(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.OUTXZ.coeffs);
        end
    end


    indOutY = find( magData_Outboard(1:end-1,2) - magData_Outboard(2:end,2) == -3)+1;
    for i=1:numel(indOutY)
        if indOutY(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutY(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutY(i):indOutY(i)+coeffLen-1) = OutXadc(indOutY(i):indOutY(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.OUTYX.coeffs);
            OutYadc(indOutY(i):indOutY(i)+coeffLen-1) = OutYadc(indOutY(i):indOutY(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.OUTYY.coeffs);
            OutZadc(indOutY(i):indOutY(i)+coeffLen-1) = OutZadc(indOutY(i):indOutY(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.OUTYZ.coeffs);
        end
    end

    indOutY = find( magData_Outboard(1:end-1,2) - magData_Outboard(2:end,2) == 3)+1;
    for i=1:numel(indOutY)
        if indOutY(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutY(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutY(i):indOutY(i)+coeffLen-1) = OutXadc(indOutY(i):indOutY(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.OUTYX.coeffs);
            OutYadc(indOutY(i):indOutY(i)+coeffLen-1) = OutYadc(indOutY(i):indOutY(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.OUTYY.coeffs);
            OutZadc(indOutY(i):indOutY(i)+coeffLen-1) = OutZadc(indOutY(i):indOutY(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.OUTYZ.coeffs);
        end
    end


    indOutZ = find( magData_Outboard(1:end-1,3) - magData_Outboard(2:end,3) == -3)+1;
    for i=1:numel(indOutZ)
        if indOutZ(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutZ(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.OUTZX.coeffs);
            OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.OUTZY.coeffs);
            OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) + 1.5*transpose(tickCoeffAtTemp.OUTZZ.coeffs);
        end
    end

    indOutZ = find( magData_Outboard(1:end-1,3) - magData_Outboard(2:end,3) == 3)+1;
    for i=1:numel(indOutZ)
        if indOutZ(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutZ(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.OUTZX.coeffs);
            OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.OUTZY.coeffs);
            OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) - 1.5*transpose(tickCoeffAtTemp.OUTZZ.coeffs);
        end
    end
    

    % Stepping by +/- 4
    indOutX = find( magData_Outboard(1:end-1,1) - magData_Outboard(2:end,1) == -4)+1;
    for i=1:numel(indOutX)
        if indOutX(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutX(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutX(i):indOutX(i)+coeffLen-1) = OutXadc(indOutX(i):indOutX(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.OUTXX.coeffs);
            OutYadc(indOutX(i):indOutX(i)+coeffLen-1) = OutYadc(indOutX(i):indOutX(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.OUTXY.coeffs);
            OutZadc(indOutX(i):indOutX(i)+coeffLen-1) = OutZadc(indOutX(i):indOutX(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.OUTXZ.coeffs);
        end
    end

    indOutX = find( magData_Outboard(1:end-1,1) - magData_Outboard(2:end,1) == 4)+1;
    for i=1:numel(indOutX)
        if indOutX(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutX(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutX(i):indOutX(i)+coeffLen-1) = OutXadc(indOutX(i):indOutX(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.OUTXX.coeffs);
            OutYadc(indOutX(i):indOutX(i)+coeffLen-1) = OutYadc(indOutX(i):indOutX(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.OUTXY.coeffs);
            OutZadc(indOutX(i):indOutX(i)+coeffLen-1) = OutZadc(indOutX(i):indOutX(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.OUTXZ.coeffs);
        end
    end


    indOutY = find( magData_Outboard(1:end-1,2) - magData_Outboard(2:end,2) == -4)+1;
    for i=1:numel(indOutY)
        if indOutY(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutY(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutY(i):indOutY(i)+coeffLen-1) = OutXadc(indOutY(i):indOutY(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.OUTYX.coeffs);
            OutYadc(indOutY(i):indOutY(i)+coeffLen-1) = OutYadc(indOutY(i):indOutY(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.OUTYY.coeffs);
            OutZadc(indOutY(i):indOutY(i)+coeffLen-1) = OutZadc(indOutY(i):indOutY(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.OUTYZ.coeffs);
        end
    end

    indOutY = find( magData_Outboard(1:end-1,2) - magData_Outboard(2:end,2) == 4)+1;
    for i=1:numel(indOutY)
        if indOutY(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutY(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutY(i):indOutY(i)+coeffLen-1) = OutXadc(indOutY(i):indOutY(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.OUTYX.coeffs);
            OutYadc(indOutY(i):indOutY(i)+coeffLen-1) = OutYadc(indOutY(i):indOutY(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.OUTYY.coeffs);
            OutZadc(indOutY(i):indOutY(i)+coeffLen-1) = OutZadc(indOutY(i):indOutY(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.OUTYZ.coeffs);
        end
    end


    indOutZ = find( magData_Outboard(1:end-1,3) - magData_Outboard(2:end,3) == -4)+1;
    for i=1:numel(indOutZ)
        if indOutZ(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutZ(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.OUTZX.coeffs);
            OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.OUTZY.coeffs);
            OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) + 2*transpose(tickCoeffAtTemp.OUTZZ.coeffs);
        end
    end

    indOutZ = find( magData_Outboard(1:end-1,3) - magData_Outboard(2:end,3) == 4)+1;
    for i=1:numel(indOutZ)
        if indOutZ(i) < numel(OutXadc) - coeffLen
            tickCoeffAtTemp = getTickCoeffByTemp(getTempAtTime(t_fit(indOutZ(i)), t_hk, hk_Inboard.Tebox), tickCoeffs, tempInd);
            OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutXadc(indOutZ(i):indOutZ(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.OUTZX.coeffs);
            OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutYadc(indOutZ(i):indOutZ(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.OUTZY.coeffs);
            OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) = OutZadc(indOutZ(i):indOutZ(i)+coeffLen-1) - 2*transpose(tickCoeffAtTemp.OUTZZ.coeffs);
        end
    end
    
end


%% Construct Raw B Arrays
B_Inboard = nan(numel(t_fit), 3);
B_Outboard = nan(numel(t_fit), 3);

B_Inboard(:,1) = 32.0*magData_Inboard(:,1) + 0.0625*InXadc;
B_Inboard(:,2) = 32.0*magData_Inboard(:,2) + 0.0625*InYadc;
B_Inboard(:,3) = 32.0*magData_Inboard(:,3) + 0.0625*InZadc;

B_Outboard(:,1) = 32.0*magData_Outboard(:,1) + 0.0625*OutXadc;
B_Outboard(:,2) = 32.0*magData_Outboard(:,2) + 0.0625*OutYadc;
B_Outboard(:,3) = 32.0*magData_Outboard(:,3) + 0.0625*OutZadc;



%% Truncate to real data

if (p.Results.truncateToReal == 0)
    logStruct = mgfLog(logStruct,sprintf('Outboard - Truncating to non-NaN date disabled by command line.\n'), 'warn');
else
    realDataInd = find(~isnan(B_Inboard(:,1)) & ~isnan(B_Inboard(:,2)) & ~isnan(B_Inboard(:,3)) & ~isnan(B_Outboard(:,1)) & ~isnan(B_Outboard(:,2)) & ~isnan(B_Outboard(:,3)) );

    if (isempty(realDataInd))
        logStruct = mgfLog(logStruct, sprintf('No non-NaN data in magnetic field data.\n'), 'error');
        mgfLogDump(logStruct);
        return;
    end

    minRealData = 1000;
    if (numel(realDataInd) < minRealData)
        logStruct = mgfLog(logStruct, sprintf('Less than %d real data points found. Terminating.\n', numel(realDataInd) ), 'error');
        mgfLogDump(logStruct);
        return;
    end

    logStruct = mgfLog(logStruct, sprintf('Culling data to interval %s to %s where all data in valid.\n', t_fit(realDataInd(1)), t_fit(realDataInd(end)) ), 'info');

    t_fit = t_fit(realDataInd(1):realDataInd(end));
    B_Inboard = B_Inboard(realDataInd(1):realDataInd(end), :);
    B_Outboard = B_Outboard(realDataInd(1):realDataInd(end), :);
    magData_Inboard = magData_Inboard(realDataInd(1):realDataInd(end), :);
    magData_Outboard = magData_Outboard(realDataInd(1):realDataInd(end), :);
    DAC_Inboard = DAC_Inboard(realDataInd(1):realDataInd(end), :);
    DAC_Outboard = DAC_Outboard(realDataInd(1):realDataInd(end), :);
end

%% If asked, create the detick plot.

if (p.Results.detickPlot)
    fprintf('Creating detick plot.\n');
    mgf_detickPlot(B_Inboard(:,1), magData_Inboard(:,1), magData_Inboard(:,2), magData_Inboard(:,3), 'Inboard Bx')
    mgf_detickPlot(B_Inboard(:,2), magData_Inboard(:,1), magData_Inboard(:,2), magData_Inboard(:,3), 'Inboard By')
    mgf_detickPlot(B_Inboard(:,3), magData_Inboard(:,1), magData_Inboard(:,2), magData_Inboard(:,3), 'Inboard Bz')
    
    mgf_detickPlot(B_Outboard(:,1), magData_Outboard(:,1), magData_Outboard(:,2), magData_Outboard(:,3), 'Outboard Bx')
    mgf_detickPlot(B_Outboard(:,2), magData_Outboard(:,1), magData_Outboard(:,2), magData_Outboard(:,3), 'Outboard By')
    mgf_detickPlot(B_Outboard(:,3), magData_Outboard(:,1), magData_Outboard(:,2), magData_Outboard(:,3), 'Outboard Bz')
end


%% Fill in the metadata

metadata.Level1 = struct;
metadata.Level1.StartTime = min(t_fit);
metadata.Level1.EndTime =  max(t_fit);

%% Generate output filename

outputFileName = genFileName( metadata.Level1.StartTime, metadata.Level1.EndTime, curLevel+1, defs.Version );

outputFileNameFull = strcat(p.Results.outputPath, filesep, outputFileName);

%% Save output file

logStruct = mgfLog(logStruct, sprintf("Saving output file: %s\n", outputFileNameFull), 'info');
save(outputFileNameFull, 't_fit', 'B_Inboard', 'B_Outboard', 't_hk', 'hk_Inboard', 'hk_Outboard', 'DAC_Inboard', 'DAC_Outboard', 'metadata', 'logStruct');

end

