function [] = mgf_QuicklookPlot_par(fileName, p, logStruct_temp)
%UNTITLED5 Summary of this function goes here
%   Detailed explanation goes here


if isempty(logStruct_temp)
    logStruct_temp = struct;
end

logStruct_temp = mgfLogInit( logStruct_temp, mfilename(), p, fileName, '', 'msg' );

[ retVal, tStart, tEnd, dataLevel, logStruct_temp ] = mgfParseFilename( fileName, logStruct_temp );

if retVal
   logStruct_temp = mgfLog(logStruct_temp, sprintf('mgfParseFilename returned %d.', retVal), 'error');
   mgfLogDump(logStruct_temp);
   return;
end

load(fileName,'-mat');

logStruct.text = [logStruct.text logStruct_temp.text];
logStruct.fileName = logStruct_temp.fileName;
logStruct.callingFileName = logStruct_temp.callingFileName;
logStruct.level = logStruct_temp.level;

logStruct = mgfLogInit( logStruct, mfilename(), p, fileName, '.QuicklookPlot', 'warn' );

xRange = [min(t_fit) max(t_fit)];

titleDate = t_fit(1);
titleDate.Format = 'MMMM d, yyyy';

titleStartTime = t_fit(1);
titleStartTime.Format = 'HH:mm:ss';

titleStopTime = t_fit(end);
titleStopTime.Format = 'HH:mm:ss';

cRange = [-25 10];


BMag_Inboard = sqrt(B_Inboard(:,1).^2 + B_Inboard(:,2).^2 + B_Inboard(:,3).^2);
BMag_Outboard = sqrt(B_Outboard(:,1).^2 + B_Outboard(:,2).^2 + B_Outboard(:,3).^2);


%% Interpolate the lv2 data before we take FFT
B_Inboard(isnan(B_Inboard(:,1)),1) = interp1(t_fit(~isnan(B_Inboard(:,1))),B_Inboard(~isnan(B_Inboard(:,1)),1),t_fit(isnan(B_Inboard(:,1))),'spline');
B_Inboard(isnan(B_Inboard(:,2)),2) = interp1(t_fit(~isnan(B_Inboard(:,2))),B_Inboard(~isnan(B_Inboard(:,2)),2),t_fit(isnan(B_Inboard(:,2))),'spline');
B_Inboard(isnan(B_Inboard(:,3)),3) = interp1(t_fit(~isnan(B_Inboard(:,3))),B_Inboard(~isnan(B_Inboard(:,3)),3),t_fit(isnan(B_Inboard(:,3))),'spline');

B_Outboard(isnan(B_Outboard(:,1)),1) = interp1(t_fit(~isnan(B_Outboard(:,1))),B_Outboard(~isnan(B_Outboard(:,1)),1),t_fit(isnan(B_Outboard(:,1))),'spline');
B_Outboard(isnan(B_Outboard(:,2)),2) = interp1(t_fit(~isnan(B_Outboard(:,2))),B_Outboard(~isnan(B_Outboard(:,2)),2),t_fit(isnan(B_Outboard(:,2))),'spline');
B_Outboard(isnan(B_Outboard(:,3)),3) = interp1(t_fit(~isnan(B_Outboard(:,3))),B_Outboard(~isnan(B_Outboard(:,3)),3),t_fit(isnan(B_Outboard(:,3))),'spline');



%% Create dynamic spectra for inboard and outboard.
overlap = 256;
nfft = 512;
Fs = 160;

[FXI, TXI, PSDXI, PSXI, LSDXI, LSXI, ENBWXI ] = quantSpectrogram(B_Inboard(:,1),t_fit,nfft,overlap,Fs);
[FYI, TYI, PSDYI, PSYI, LSDYI, LSYI, ENBWYI ] = quantSpectrogram(B_Inboard(:,2),t_fit,nfft,overlap,Fs);
[FZI, TZI, PSDZI, PSZI, LSDZI, LSZI, ENBWZI ] = quantSpectrogram(B_Inboard(:,3),t_fit,nfft,overlap,Fs);

PI = transpose(sqrt(PSDXI.^2 + PSDYI.^2 + PSDZI.^2));


[FXO, TXO, PSDXO, PSXO, LSDXO, LSXO, ENBWXO ] = quantSpectrogram(B_Outboard(:,1),t_fit,nfft,overlap,Fs);
[FYO, TYO, PSDYO, PSYO, LSDYO, LSYO, ENBWYO ] = quantSpectrogram(B_Outboard(:,2),t_fit,nfft,overlap,Fs);
[FZO, TZO, PSDZO, PSZO, LSDZO, LSZO, ENBWZO ] = quantSpectrogram(B_Outboard(:,3),t_fit,nfft,overlap,Fs);
PO = transpose(sqrt(PSDXO.^2 + PSDYO.^2 + PSDZO.^2));

%% Create deltas for Vmon1 and Vmon2

hk_Inboard_DeltaVmon1 = 1000*( 5.0 - hk_Inboard.Vmon1);
hk_Inboard_DeltaVmon2 = 1000*(-5.0 - hk_Inboard.Vmon2);
hk_Outboard_DeltaVmon1 = 1000*( 5.0 - hk_Outboard.Vmon1);
hk_Outboard_DeltaVmon2 = 1000*(-5.0 - hk_Outboard.Vmon2);

%% Create the figure for the plot
figHandle = figure;
figHandle.Units = 'Inch';
figHandle.Position = [0 0 8.5 11];


%% Outboard Spectrogram
p1 = subplot(6,1,1);

surf(TXO,FXO,10*log10(sqrt(abs(PO))), 'linestyle', 'none');
view(0,90);

caxis(cRange);

xlim( [min(TXO) max(TXO)] );
ylim( [min(FXO) max(FXO)] );

grid on;
ylabel({'Outboard Sensor','Frequency (Hz)'});

p1.XTickLabel = [];


%% Title for plots
title({'Swarm Echo Quicklook Plot',sprintf('%s from %s to %s', titleDate, titleStartTime, titleStopTime)});


%% Inboard Spectrogram
p2 = subplot(6,1,2);

surf(TXI,FXI,10*log10(sqrt(abs(PI))), 'linestyle', 'none');
view(0,90);

caxis(cRange);

xlim( [min(TXI) max(TXI)] );
ylim( [min(FXI) max(FXI)] );

grid on;
ylabel({'Inboard Sensor','Frequency (Hz)'});

cbar = colorbar('east');
cbar.Position = cbar.Position + [0.095 0 0.00 0.15 ];
cbar.Label.String = 'Log_{10} (nT^2/Hz)';

p2.XTickLabel = [];


%% Total Field

p3 = subplot(6, 1, [3 4]);

plot(t_fit, BMag_Inboard, 'b', t_fit, BMag_Outboard, 'g');
xlim(xRange);
grid on;
ylabel({'Total Field','|B| (nT)'});

legend({'Inboard Mag','Outboard Mag'},'Location','NorthEast');


%% Temperatures
p5 = subplot(6,1,5);

hat = 1;

plot(t_hk, hk_Inboard.Tebox, 'b', ...
     t_hk, hk_Inboard.Tsensor, 'c', ...
     t_hk, hk_Outboard.Tebox, 'g', ...
     t_hk, hk_Outboard.Tsensor, 'y' );

xlim(xRange);
grid on;

ylabel({'Temperature', ['(' char(176) 'C)' ]});
p5.XTickLabel = [];


%% Voltages
p6 = subplot(6,1,6);

plot(t_hk, hk_Inboard_DeltaVmon1, 'b', ...
     t_hk, hk_Inboard_DeltaVmon2, 'c', ...
     t_hk, hk_Outboard_DeltaVmon1, 'g', ...
     t_hk, hk_Outboard_DeltaVmon2, 'y' );


xlim(xRange);
ylim([-100 100]);
grid on;
ylabel({'Voltage','(mV)'});

p6.YTickLabel = sprintf('%3.0f\n',p6.YTick);
xlabel('Time (UTC)');



%% Save plot
[justFilePath,justFileName,justFileExt] = fileparts(fileName);
outputFileName = strcat(justFileName, '.Quicklook.png');
outputFileNameFull = strcat(p.Results.outputPath, filesep, outputFileName);

logStruct = mgfLog(logStruct, sprintf("INFO:  Saving output file: %s\n", outputFileNameFull), 'info');

saveas(figHandle,outputFileNameFull);

%% Close plot unless interactive mode is set
if ~p.Results.interactive
    close(figHandle);
end



%% Debug plot showing all fft channels.
figHandle2 = figure;
figHandle2.Units = 'Inch';
figHandle2.Position = [0 0 8.5 11];

p1 = subplot(6,1,1);
surf(TXO,FXO,10*log10(sqrt(abs(transpose(PSDXI)))), 'linestyle', 'none');
view(0,90);
caxis(cRange);
xlim( [min(TXO) max(TXO)] );
ylim( [min(FXO) max(FXO)] );
grid on;
ylabel({'Inboard X','Frequency (Hz)'});
p1.XTickLabel = [];

%% Title for plots
title({'Swarm Echo Quicklook FFT Plot',sprintf('%s from %s to %s', titleDate, titleStartTime, titleStopTime)});

p2 = subplot(6,1,2);
surf(TXO,FXO,10*log10(sqrt(abs(transpose(PSDYI)))), 'linestyle', 'none');
view(0,90);
caxis(cRange);
xlim( [min(TXO) max(TXO)] );
ylim( [min(FXO) max(FXO)] );
grid on;
ylabel({'Inboard Y','Frequency (Hz)'});
p2.XTickLabel = [];

p3 = subplot(6,1,3);
surf(TXO,FXO,10*log10(sqrt(abs(transpose(PSDZI)))), 'linestyle', 'none');
view(0,90);
caxis(cRange);
xlim( [min(TXO) max(TXO)] );
ylim( [min(FXO) max(FXO)] );
grid on;
ylabel({'Inboard Z','Frequency (Hz)'});
p3.XTickLabel = [];

p4 = subplot(6,1,4);
surf(TXO,FXO,10*log10(sqrt(abs(transpose(PSDXO)))), 'linestyle', 'none');
view(0,90);
caxis(cRange);
xlim( [min(TXO) max(TXO)] );
ylim( [min(FXO) max(FXO)] );
grid on;
ylabel({'Outboard X','Frequency (Hz)'});
p4.XTickLabel = [];

p5 = subplot(6,1,5);
surf(TXO,FXO,10*log10(sqrt(abs(transpose(PSDYO)))), 'linestyle', 'none');
view(0,90);
caxis(cRange);
xlim( [min(TXO) max(TXO)] );
ylim( [min(FXO) max(FXO)] );
grid on;
ylabel({'Outboard Y','Frequency (Hz)'});
p5.XTickLabel = [];

p6 = subplot(6,1,6);
surf(TXO,FXO,10*log10(sqrt(abs(transpose(PSDZO)))), 'linestyle', 'none');
view(0,90);
caxis(cRange);
xlim( [min(TXO) max(TXO)] );
ylim( [min(FXO) max(FXO)] );
grid on;
ylabel({'Outboard Z','Frequency (Hz)'});

p6.YTickLabel = sprintf('%3.0f\n',p6.YTick);
xlabel('Time (UTC)');


%% Save plot
[justFilePath,justFileName,justFileExt] = fileparts(fileName);
outputFileName = strcat(justFileName, '.Quicklook.ffts.png');
outputFileNameFull = strcat(p.Results.outputPath, filesep, outputFileName);

logStruct = mgfLog(logStruct, sprintf("INFO:  Saving output file: %s\n", outputFileNameFull), 'info');

saveas(figHandle2,outputFileNameFull);

%% Close plot unless interactive mode is set
if ~p.Results.interactive
    close(figHandle2);
end



end

