function [ output_args ] = mgf_SummaryPlot( varargin )
%Initial file used to generte MGF Summary plots.  Set input path to
%location of MGF lv2 data files.  File will call MGF_SUMMARY and output the
%completed plot to the diesired output path.
%File initially created by David Miles.
%File edited by Robert Broadfoot 06/25/2019
default_inputPath = '.\'; % Path to mgf files
default_outputPath = '.\'; % Output for summary plot
default_attitudePath = '.\'; %Path to quaternions for getAttitude
default_locationPath = '.\'; %Path to mat files containing position and velocity data for getLocationpar
default_searchString = '*.lv2';
default_interactive = 0;

p = inputParser;
p.addParameter('inputPath', default_inputPath, @ischar);
p.addParameter('outputPath', default_outputPath, @ischar);
p.addParameter('attitudePath',default_attitudePath, @ischar);
p.addParameter('locationPath',default_locationPath, @ischar);
p.addParameter('searchString', default_searchString, @ischar);
p.addParameter('interactive', default_interactive, @isnumeric);
p.parse(varargin{:});

logStruct_temp = struct;
logStruct_temp = mgfLogInit( logStruct_temp, mfilename(), p, '', '.SummaryPlot', 'msg' );

fullSearchString = strcat(p.Results.inputPath,filesep,p.Results.searchString);

logStruct_temp = mgfLog( logStruct_temp, sprintf('Checking %s\n', fullSearchString), 'msg');

fileList = dir( fullSearchString );
numFiles = sum(~[fileList.isdir]);
numDirs = sum([fileList.isdir]);

logStruct_temp = mgfLog( logStruct_temp, sprintf('Found %d files. Excluding %d directories.\n', numFiles, numDirs ), 'msg');

if( numFiles > 0)
    parfor j = 1:numel(fileList)
        if (~fileList(j).isdir)
           fileName = strcat(p.Results.inputPath,filesep,fileList(j).name);
           logStruct_for = mgfLog(logStruct_temp, sprintf('%s: Starting file ''%s''\n', mfilename(), fileName), 'msg' );

           try
                MGF_SUMMARY(fileName, p, logStruct_for );
           catch EM
             logStruct_for = mgfLog(logStruct_temp, sprintf('%s: Caught error %s with message %s.\n', mfilename(), EM.identifier, EM.message), 'ERROR');
             logStruct_for.fileName = fileName;
             mgfLogDump( logStruct_for );
           end
        end
    end
end
end

