function [] = mgf_SummaryPlot_par(fileName, p, logStruct_temp)
%UNTITLED6 Summary of this function goes here
%   Detailed explanation goes here

if isempty(logStruct_temp)
    logStruct_temp = struct;
end

logStruct_temp = mgfLogInit( logStruct_temp, mfilename(), p, fileName, '', 'msg' );

[ retVal, tStart, tEnd, dataLevel, logStruct_temp ] = mgfParseFilename( fileName, logStruct_temp );

if retVal
   logStruct_temp = mgfLog(logStruct_temp, sprintf('mgfParseFilename returned %d.', retVal), 'error');
   mgfLogDump(logStruct_temp);
   return;
end

load(fileName,'-mat');

logStruct.text = [logStruct.text logStruct_temp.text];
logStruct.fileName = logStruct_temp.fileName;
logStruct.callingFileName = logStruct_temp.callingFileName;
logStruct.level = logStruct_temp.level;

xRange = [min(t_fit) max(t_fit)];

titleDate = t_fit(1);
titleDate.Format = 'MMMM d, yyyy';

titleStartTime = t_fit(1);
titleStartTime.Format = 'HH:mm:ss';

titleStopTime = t_fit(end);
titleStopTime.Format = 'HH:mm:ss';

BMag_Inboard = sqrt(B_Inboard(:,1).^2 + B_Inboard(:,2).^2 + B_Inboard(:,3).^2);
BMag_Outboard = sqrt(B_Outboard(:,1).^2 + B_Outboard(:,2).^2 + B_Outboard(:,3).^2);



%% Create the figure for the plot
figHandle = figure;
figHandle.Units = 'Inch';
figHandle.Position = [0 0 8.5 11];


%% X Component
p1 = subplot(4,1,1);
plot(t_fit, B_Inboard(:,1), 'b', t_fit, B_Outboard(:,1), 'g');
xlim(xRange);
grid on;
ylabel({'Sensor Coordinates','B_x (nT)'});

p1.XTickLabel = [];
p1.YTickLabel = sprintf('%5.0f\n',p1.YTick);

%% Title for plots
title({'Swarm Echo Summary Plot',sprintf('%s from %s to %s', titleDate, titleStartTime, titleStopTime)});


%% Y Component
p2 = subplot(4,1,2);
plot(t_fit, B_Inboard(:,1), 'b', t_fit, B_Outboard(:,1), 'g');
xlim(xRange);
grid on;
ylabel({'Sensor Coordinates','B_y (nT)'});

p2.XTickLabel = [];
p2.YTickLabel = sprintf('%5.0f\n',p1.YTick);


%% Z Component
p3 = subplot(4,1,3);
plot(t_fit, B_Inboard(:,1), 'b', t_fit, B_Outboard(:,1), 'g');
xlim(xRange);
grid on;
ylabel({'Sensor Coordinates','B_z (nT)'});

p3.XTickLabel = [];
p3.YTickLabel = sprintf('%5.0f\n',p1.YTick);


%% |B| 
p4 = subplot(4,1,4);
plot(t_fit, BMag_Inboard, 'b', t_fit, BMag_Outboard, 'g');
xlim(xRange);
grid on;
ylabel({'Sensor Coordinates','|B| (nT)'});

p4.YTickLabel = sprintf('%5.0f\n',p4.YTick);
xlabel('Time (UTC)');



%% Save plot
[justFilePath,justFileName,justFileExt] = fileparts(fileName);
outputFileName = strcat(justFileName, '.Summary.png');
outputFileNameFull = strcat(p.Results.outputPath, filesep, outputFileName);

logStruct = mgfLog(logStruct, sprintf('Saving output file: ''%s''\n', outputFileNameFull), 'info');

saveas(figHandle,outputFileNameFull);

%% Close plot unless interactive mode is set
if ~p.Results.interactive
    close(figHandle);
end

end

